@@ -112,9 +112,6 @@ namespace Ogre
         /** Creates a specialized PCZCamera */
         Camera * createCamera( const String &name ) override;
 
-        /** Deletes a scene node by name & corresponding PCZSceneNode */
-        void destroySceneNode( const String &name ) override;
-
         /** Deletes a scene node & corresponding PCZSceneNode */
         void destroySceneNode(SceneNode* sn) override;
 
@@ -294,7 +291,7 @@ namespace Ogre
         void _clearAllZonesPortalUpdateFlag(void);
 
         /// @see SceneManager::prepareShadowTextures.
-        void prepareShadowTextures(Camera* cam, Viewport* vp, const LightList* lightList = 0) override;
+        void updateShadowTextures(Camera* cam, Viewport* vp, const LightList* lightList = 0) override;
 
     protected:
         /// Type of default zone to be used
