@@ -137,10 +137,11 @@ var _scripts =
         [ "param_indexed_auto", "_high-level-_programs.html#autotoc_md195", null ],
         [ "param_named", "_high-level-_programs.html#autotoc_md196", null ],
         [ "param_named_auto", "_high-level-_programs.html#autotoc_md197", null ],
-        [ "shared_params_ref", "_high-level-_programs.html#autotoc_md198", null ]
+        [ "shared_params_ref", "_high-level-_programs.html#autotoc_md198", null ],
+        [ "use_linear_colours", "_high-level-_programs.html#autotoc_md199", null ]
       ] ],
       [ "Declaring Shared Parameters", "_high-level-_programs.html#Declaring-Shared-Parameters", [
-        [ "Hardware Support", "_high-level-_programs.html#autotoc_md199", null ]
+        [ "Hardware Support", "_high-level-_programs.html#autotoc_md200", null ]
       ] ],
       [ "Shadows and Vertex Programs", "_high-level-_programs.html#Shadows-and-Vertex-Programs", null ],
       [ "Instancing in Vertex Programs", "_high-level-_programs.html#Instancing-in-Vertex-Programs", null ],
@@ -148,10 +149,10 @@ var _scripts =
       [ "Morph Animation in Vertex Programs", "_high-level-_programs.html#Morph-Animation-in-Vertex-Programs", null ],
       [ "Pose Animation in Vertex Programs", "_high-level-_programs.html#Pose-Animation-in-Vertex-Programs", null ],
       [ "Vertex Texture Fetch", "_high-level-_programs.html#Vertex-Texture-Fetch", [
-        [ "Declaring the use of vertex texture fetching", "_high-level-_programs.html#autotoc_md200", null ],
-        [ "DirectX9 binding limitations", "_high-level-_programs.html#autotoc_md201", null ],
-        [ "Texture format limitations", "_high-level-_programs.html#autotoc_md202", null ],
-        [ "Hardware limitations", "_high-level-_programs.html#autotoc_md203", null ]
+        [ "Declaring the use of vertex texture fetching", "_high-level-_programs.html#autotoc_md201", null ],
+        [ "DirectX9 binding limitations", "_high-level-_programs.html#autotoc_md202", null ],
+        [ "Texture format limitations", "_high-level-_programs.html#autotoc_md203", null ],
+        [ "Hardware limitations", "_high-level-_programs.html#autotoc_md204", null ]
       ] ],
       [ "Programmatic creation", "_high-level-_programs.html#GpuProgram-API", null ]
     ] ],
@@ -207,45 +208,45 @@ var _scripts =
     ] ],
     [ "Particle Scripts", "_particle-_scripts.html", [
       [ "Particle System Attributes", "_particle-_scripts.html#Particle-System-Attributes", [
-        [ "quota", "_particle-_scripts.html#autotoc_md206", null ],
-        [ "material", "_particle-_scripts.html#autotoc_md207", null ],
-        [ "particle_width", "_particle-_scripts.html#autotoc_md208", null ],
-        [ "particle_height", "_particle-_scripts.html#autotoc_md209", null ],
-        [ "cull_each", "_particle-_scripts.html#autotoc_md210", null ],
-        [ "renderer", "_particle-_scripts.html#autotoc_md211", null ],
-        [ "sorted", "_particle-_scripts.html#autotoc_md212", null ],
-        [ "local_space", "_particle-_scripts.html#autotoc_md213", null ],
-        [ "iteration_interval", "_particle-_scripts.html#autotoc_md214", null ],
-        [ "nonvisible_update_timeout", "_particle-_scripts.html#autotoc_md215", null ]
+        [ "quota", "_particle-_scripts.html#autotoc_md207", null ],
+        [ "material", "_particle-_scripts.html#autotoc_md208", null ],
+        [ "particle_width", "_particle-_scripts.html#autotoc_md209", null ],
+        [ "particle_height", "_particle-_scripts.html#autotoc_md210", null ],
+        [ "cull_each", "_particle-_scripts.html#autotoc_md211", null ],
+        [ "renderer", "_particle-_scripts.html#autotoc_md212", null ],
+        [ "sorted", "_particle-_scripts.html#autotoc_md213", null ],
+        [ "local_space", "_particle-_scripts.html#autotoc_md214", null ],
+        [ "iteration_interval", "_particle-_scripts.html#autotoc_md215", null ],
+        [ "nonvisible_update_timeout", "_particle-_scripts.html#autotoc_md216", null ]
       ] ],
       [ "Billboard Renderer Attributes", "_particle-_scripts.html#Billboard-Renderer-Attributes", [
-        [ "billboard_type", "_particle-_scripts.html#autotoc_md216", null ],
-        [ "billboard_origin", "_particle-_scripts.html#autotoc_md217", null ],
-        [ "billboard_rotation_type", "_particle-_scripts.html#autotoc_md218", null ],
-        [ "common_direction", "_particle-_scripts.html#autotoc_md219", null ],
-        [ "common_up_vector", "_particle-_scripts.html#autotoc_md220", null ],
-        [ "point_rendering", "_particle-_scripts.html#autotoc_md221", null ],
-        [ "accurate_facing", "_particle-_scripts.html#autotoc_md222", null ],
-        [ "texture_sheet_size", "_particle-_scripts.html#autotoc_md223", null ]
+        [ "billboard_type", "_particle-_scripts.html#autotoc_md217", null ],
+        [ "billboard_origin", "_particle-_scripts.html#autotoc_md218", null ],
+        [ "billboard_rotation_type", "_particle-_scripts.html#autotoc_md219", null ],
+        [ "common_direction", "_particle-_scripts.html#autotoc_md220", null ],
+        [ "common_up_vector", "_particle-_scripts.html#autotoc_md221", null ],
+        [ "point_rendering", "_particle-_scripts.html#autotoc_md222", null ],
+        [ "accurate_facing", "_particle-_scripts.html#autotoc_md223", null ],
+        [ "texture_sheet_size", "_particle-_scripts.html#autotoc_md224", null ]
       ] ],
       [ "Particle Emitters", "_particle-_scripts.html#Particle-Emitters", [
         [ "Emitting Emitters", "_particle-_scripts.html#Emitting-Emitters", null ],
-        [ "Common Emitter Attributes", "_particle-_scripts.html#autotoc_md224", null ],
-        [ "angle", "_particle-_scripts.html#autotoc_md225", null ],
-        [ "colour", "_particle-_scripts.html#autotoc_md226", null ],
-        [ "colour_range_start &amp; colour_range_end", "_particle-_scripts.html#autotoc_md227", null ],
-        [ "direction", "_particle-_scripts.html#autotoc_md228", null ],
-        [ "direction_position_reference", "_particle-_scripts.html#autotoc_md229", null ],
-        [ "emission_rate", "_particle-_scripts.html#autotoc_md230", null ],
-        [ "position", "_particle-_scripts.html#autotoc_md231", null ],
-        [ "velocity", "_particle-_scripts.html#autotoc_md232", null ],
-        [ "velocity_min &amp; velocity_max", "_particle-_scripts.html#autotoc_md233", null ],
-        [ "time_to_live", "_particle-_scripts.html#autotoc_md234", null ],
-        [ "time_to_live_min &amp; time_to_live_max", "_particle-_scripts.html#autotoc_md235", null ],
-        [ "duration", "_particle-_scripts.html#autotoc_md236", null ],
-        [ "duration_min &amp; duration_max", "_particle-_scripts.html#autotoc_md237", null ],
-        [ "repeat_delay", "_particle-_scripts.html#autotoc_md238", null ],
-        [ "repeat_delay_min &amp; repeat_delay_max", "_particle-_scripts.html#autotoc_md239", null ]
+        [ "Common Emitter Attributes", "_particle-_scripts.html#autotoc_md225", null ],
+        [ "angle", "_particle-_scripts.html#autotoc_md226", null ],
+        [ "colour", "_particle-_scripts.html#autotoc_md227", null ],
+        [ "colour_range_start &amp; colour_range_end", "_particle-_scripts.html#autotoc_md228", null ],
+        [ "direction", "_particle-_scripts.html#autotoc_md229", null ],
+        [ "direction_position_reference", "_particle-_scripts.html#autotoc_md230", null ],
+        [ "emission_rate", "_particle-_scripts.html#autotoc_md231", null ],
+        [ "position", "_particle-_scripts.html#autotoc_md232", null ],
+        [ "velocity", "_particle-_scripts.html#autotoc_md233", null ],
+        [ "velocity_min &amp; velocity_max", "_particle-_scripts.html#autotoc_md234", null ],
+        [ "time_to_live", "_particle-_scripts.html#autotoc_md235", null ],
+        [ "time_to_live_min &amp; time_to_live_max", "_particle-_scripts.html#autotoc_md236", null ],
+        [ "duration", "_particle-_scripts.html#autotoc_md237", null ],
+        [ "duration_min &amp; duration_max", "_particle-_scripts.html#autotoc_md238", null ],
+        [ "repeat_delay", "_particle-_scripts.html#autotoc_md239", null ],
+        [ "repeat_delay_min &amp; repeat_delay_max", "_particle-_scripts.html#autotoc_md240", null ]
       ] ],
       [ "Standard Particle Emitters", "_particle-_scripts.html#Standard-Particle-Emitters", [
         [ "Point Emitter", "_particle-_scripts.html#Point-Emitter", null ],
