@@ -55,6 +55,8 @@ var class_ogre_1_1_r_t_shader_1_1_shader_generator =
     [ "getCreateShaderOverProgrammablePass", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#a6de4a29532eeca2dd8f8a44e78c05e3a", null ],
     [ "getRTShaderSchemeCount", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#aff76240698adc0202e64be7055613015", null ],
     [ "getRTShaderScheme", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#a0636f7dcc95570bc6ce4071935037654", null ],
+    [ "setTargetLinearColours", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#ae6919b349581e860e7fd5b69892e2d21", null ],
+    [ "getTargetLinearColours", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#af7ee0051c5d8eada7c7c53a1fa87ebb1", null ],
     [ "_markNonFFP", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#abbc0c7972a0f56fcb5b8340150db97db", null ],
     [ "SGRenderObjectListener", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#a93b29d440457293f575d4d00f5d82a49", null ],
     [ "SGSceneManagerListener", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#a6f22fa0f80cacf8b9e587c7ec9a68477", null ],
