@@ -7,12 +7,11 @@ var group___g_l3_plus =
       [ "_initialise", "class_ogre_1_1_g_l3_plus_render_system.html#a87045d100de454fa45bb14d190366164", null ],
       [ "initConfigOptions", "class_ogre_1_1_g_l3_plus_render_system.html#a5a56ef8e3fdd74ba6b2981942b20b132", null ],
       [ "createRenderSystemCapabilities", "class_ogre_1_1_g_l3_plus_render_system.html#ac27a2fb4f50a2cbbc0caf8f1ec9f3f9c", null ],
-      [ "initialiseFromRenderSystemCapabilities", "class_ogre_1_1_g_l3_plus_render_system.html#a4e19c3e2525d7ef92570c6c0d2b7616e", null ],
+      [ "initialiseFromRenderSystemCapabilities", "class_ogre_1_1_g_l3_plus_render_system.html#a319e8889df53dba4290ce82ba295d782", null ],
       [ "shutdown", "class_ogre_1_1_g_l3_plus_render_system.html#af888cf5cd565f35f849dc47b25b62208", null ],
       [ "_createRenderWindow", "class_ogre_1_1_g_l3_plus_render_system.html#a1bf9f49c145096122e86ae0c8ce3d451", null ],
       [ "_createDepthBufferFor", "class_ogre_1_1_g_l3_plus_render_system.html#aae7538b7e61a12a6477fa149b3dcd17e", null ],
       [ "createMultiRenderTarget", "class_ogre_1_1_g_l3_plus_render_system.html#a4d289c05eb8f5e4c6ccaa906a58626b8", null ],
-      [ "destroyRenderWindow", "class_ogre_1_1_g_l3_plus_render_system.html#a6e8b4d8c863c311df23b6a81c9662ef5", null ],
       [ "_setTexture", "class_ogre_1_1_g_l3_plus_render_system.html#a476ce10061d1642f054833887a7e14c4", null ],
       [ "_setSampler", "class_ogre_1_1_g_l3_plus_render_system.html#a3d6015f1724714b02fd611c046c6ced9", null ],
       [ "_setLineWidth", "class_ogre_1_1_g_l3_plus_render_system.html#a64e939e69f77e04d2b4ea1fe028637b1", null ],
@@ -41,6 +40,7 @@ var group___g_l3_plus =
       [ "_oneTimeContextInitialization", "class_ogre_1_1_g_l3_plus_render_system.html#a4877f1512ad6cdbf31bbba8516482334", null ],
       [ "initialiseContext", "class_ogre_1_1_g_l3_plus_render_system.html#a9969e9ead963147492cc8a85bca37a93", null ],
       [ "_setRenderTarget", "class_ogre_1_1_g_l3_plus_render_system.html#ab230f53629c76f353528748734e54fc2", null ],
+      [ "bindRenderTarget", "class_ogre_1_1_g_l3_plus_render_system.html#aff6d0b692cbbb859a9e3f476aceb1275", null ],
       [ "convertCompareFunction", "class_ogre_1_1_g_l3_plus_render_system.html#aeeb44bff1b5829c3b401734693a8e072", null ],
       [ "convertStencilOp", "class_ogre_1_1_g_l3_plus_render_system.html#a60db00707d0200332b5c69a8329fb104", null ],
       [ "bindGpuProgram", "class_ogre_1_1_g_l3_plus_render_system.html#a13879f33834cf978536705153d65969a", null ],
