@@ -140,7 +140,7 @@ var group___p_c_z_scene_manager =
       [ "mPCZSM", "class_ogre_1_1_p_c_zone.html#a93e8f7a50cdea269e209fd15f87c557d", null ]
     ] ],
     [ "Ogre::PCZSceneManager", "class_ogre_1_1_p_c_z_scene_manager.html", [
-      [ "ZoneIterator", "class_ogre_1_1_p_c_z_scene_manager.html#abf3a446711cefeb7190e09b6ffaee330", null ],
+      [ "ZoneIterator", "class_ogre_1_1_p_c_z_scene_manager.html#a44d7ec7900f22ea1a1dcaf62bbe65735", null ],
       [ "PCZSceneManager", "class_ogre_1_1_p_c_z_scene_manager.html#ac6e44e60f66e1540d4c14a52aa36120c", null ],
       [ "~PCZSceneManager", "class_ogre_1_1_p_c_z_scene_manager.html#a6caa6bf780a9dd066385a14c68d1d8f2", null ],
       [ "getTypeName", "class_ogre_1_1_p_c_z_scene_manager.html#a4692cc30266e489209f652ae2fce2eff", null ],
@@ -156,7 +156,6 @@ var group___p_c_z_scene_manager =
       [ "createSceneNodeImpl", "class_ogre_1_1_p_c_z_scene_manager.html#abdad18e34d3fb9ac355bfa186726f4c1", null ],
       [ "createSceneNodeImpl", "class_ogre_1_1_p_c_z_scene_manager.html#ae16b9aad2c729ecf643ee4befa2c1299", null ],
       [ "createCamera", "class_ogre_1_1_p_c_z_scene_manager.html#a54678fa02c98f4b336c789f5b59720ea", null ],
-      [ "destroySceneNode", "class_ogre_1_1_p_c_z_scene_manager.html#a5dd6a7a34675a51deebfeb51250e3837", null ],
       [ "destroySceneNode", "class_ogre_1_1_p_c_z_scene_manager.html#a92a76aaee441c37b02eefe5291818d56", null ],
       [ "clearScene", "class_ogre_1_1_p_c_z_scene_manager.html#a91a18704ec2eb46ba4910cb39c43662d", null ],
       [ "setWorldGeometryRenderQueue", "class_ogre_1_1_p_c_z_scene_manager.html#a222a1701e1a9453b0143ea9a0076cca0", null ],
@@ -203,7 +202,7 @@ var group___p_c_z_scene_manager =
       [ "createIntersectionQuery", "class_ogre_1_1_p_c_z_scene_manager.html#aa194a8264693295fcbcdd14b9e8d325c", null ],
       [ "getZoneIterator", "class_ogre_1_1_p_c_z_scene_manager.html#ad8c3bdeb482268348587406720128530", null ],
       [ "_clearAllZonesPortalUpdateFlag", "class_ogre_1_1_p_c_z_scene_manager.html#a6b5ba29779d8d03ac92b65bd21ea615d", null ],
-      [ "prepareShadowTextures", "class_ogre_1_1_p_c_z_scene_manager.html#a68f3a812b4dd986e1f84ed27223e4963", null ],
+      [ "updateShadowTextures", "class_ogre_1_1_p_c_z_scene_manager.html#a47c37999f434fe7e788762159d06d670", null ],
       [ "PCZIntersectionSceneQuery", "class_ogre_1_1_p_c_z_scene_manager.html#a66e03b2e49e35a0f0d2b6795855e5f20", null ],
       [ "PCZRaySceneQuery", "class_ogre_1_1_p_c_z_scene_manager.html#ae08bc00b90e82c22fd5281b87c0c76f4", null ],
       [ "PCZSphereSceneQuery", "class_ogre_1_1_p_c_z_scene_manager.html#a0f46ad3758026a3cefff77b8313fb084", null ],
