@@ -1,5 +1,37 @@
 var NAVTREEINDEX10 =
 {
+"class_ogre_1_1_composition_technique_1_1_texture_definition.html#a99163323a7ab7d6b661f538b17c8f97b":[5,0,1,7,0,9],
+"class_ogre_1_1_composition_technique_1_1_texture_definition.html#aa9c8a54bdaa418233c6f10c3a8a2eb98":[5,0,1,7,0,13],
+"class_ogre_1_1_composition_technique_1_1_texture_definition.html#abbbb4c6b2ea75b413ff5534be536ad73":[5,0,1,7,0,5],
+"class_ogre_1_1_composition_technique_1_1_texture_definition.html#acdc503bc2adeee31d32988c6c994c0d6":[5,0,1,7,0,10],
+"class_ogre_1_1_composition_technique_1_1_texture_definition.html#ae59f6efc2a9d0bc5cf539c647351848d":[5,0,1,7,0,2],
+"class_ogre_1_1_composition_technique_1_1_texture_definition.html#af7cf8abd5790419f08b59519b3bb3374":[5,0,1,7,0,11],
+"class_ogre_1_1_compositor.html":[5,0,1,8],
+"class_ogre_1_1_compositor.html#a1f3a6209ce89a4105719c26e0b2a5f46":[5,0,1,8,2],
+"class_ogre_1_1_compositor.html#a34a3a5086152382d77a85c25fbabb1be":[5,0,1,8,0],
+"class_ogre_1_1_compositor.html#a446dd4a5fed791283a79d6acd9936d55":[5,0,1,8,15],
+"class_ogre_1_1_compositor.html#a52653a85d40ae889556707320a784d3e":[5,0,1,8,12],
+"class_ogre_1_1_compositor.html#a57a6ab020e5ac812bb96aa59b1497fbd":[5,0,1,8,8],
+"class_ogre_1_1_compositor.html#a65cd9c6af5f17b32283be24e0b13010f":[5,0,1,8,9],
+"class_ogre_1_1_compositor.html#a74f8cab4f5407b59a30160a1f8309cee":[5,0,1,8,14],
+"class_ogre_1_1_compositor.html#a78ac5745673e6e9f44a866ef016710cd":[5,0,1,8,3],
+"class_ogre_1_1_compositor.html#a7f8ef525639ebc764e0be2dfa1349dfd":[5,0,1,8,11],
+"class_ogre_1_1_compositor.html#aa22940bfe5308327d7f00aea0279deab":[5,0,1,8,13],
+"class_ogre_1_1_compositor.html#aae47eb9cabec8ad5c8b40a0dd0e8180d":[5,0,1,8,5],
+"class_ogre_1_1_compositor.html#acc029ae8cf6f0db569d8328621c6cd50":[5,0,1,8,1],
+"class_ogre_1_1_compositor.html#acf1dec61d4fc0b3001ed0cf4eb7e3969":[5,0,1,8,10],
+"class_ogre_1_1_compositor.html#acfdba392e0274fdbd0e4d14948bebc38":[5,0,1,8,6],
+"class_ogre_1_1_compositor.html#adf336074a45c59d05b585f0e6f745ed3":[5,0,1,8,16],
+"class_ogre_1_1_compositor.html#aed7c5f927e625cf58f65a50c9c55abe4":[5,0,1,8,4],
+"class_ogre_1_1_compositor.html#af5c1adab5d0aa7bae1374cd971162c8c":[5,0,1,8,7],
+"class_ogre_1_1_compositor_chain.html":[5,0,1,9],
+"class_ogre_1_1_compositor_chain.html#a0301254bb0cd91ca135805638301ad25":[5,0,1,9,21],
+"class_ogre_1_1_compositor_chain.html#a0786570dbe0567f781db42c64cdc0864":[5,0,1,9,22],
+"class_ogre_1_1_compositor_chain.html#a0c5a67e7aeb3f74242a45972f30073eb":[5,0,1,9,24],
+"class_ogre_1_1_compositor_chain.html#a136bcc91dece7d0c020c6bf4e635a2f3":[5,0,1,9,5],
+"class_ogre_1_1_compositor_chain.html#a1495dde8bb681d9f10563a7d3bc90581":[5,0,1,9,16],
+"class_ogre_1_1_compositor_chain.html#a16acff0bca06c03a0b3664032631dd5f":[5,0,1,9,6],
+"class_ogre_1_1_compositor_chain.html#a1e3e30292bbae6d7191bb1c4b8a4d6fb":[5,0,1,9,23],
 "class_ogre_1_1_compositor_chain.html#a2bc1594f935675eed1105b7a46a1e534":[5,0,1,9,17],
 "class_ogre_1_1_compositor_chain.html#a2f06c8b7e9bd3ab605c85b7ccbafd78d":[5,0,1,9,15],
 "class_ogre_1_1_compositor_chain.html#a3c2e3610732ee682f97a2e177168ca21":[5,0,1,9,14],
@@ -70,6 +102,7 @@ var NAVTREEINDEX10 =
 "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a4d359b9d7ce499be7c9e72e62a0a5787":[5,0,1,10,2,8],
 "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a56bb029bcccd70874ba6474e66393fdd":[5,0,1,10,2,9],
 "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a7026db7788bde13a6b6466a967733b64":[5,0,1,10,2,0],
+"class_ogre_1_1_compositor_instance_1_1_target_operation.html#a7e995420722b1cb490a87876cddf5d99":[5,0,1,10,2,16],
 "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a8ba9a8940b2e81cb3e866cce28697a4f":[5,0,1,10,2,7],
 "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a91205dfe635e89525f6080c93a913522":[5,0,1,10,2,5],
 "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a9f0ff12a7501fa0668d6ede6e18a913f":[5,0,1,10,2,15],
@@ -84,32 +117,33 @@ var NAVTREEINDEX10 =
 "class_ogre_1_1_compositor_logic.html#abaec84ca5c9b9c4f0f200596e0c90f05":[5,0,1,11,1],
 "class_ogre_1_1_compositor_logic.html#adb5d5a92b735eec00a40426bd91c4e8b":[5,0,1,11,0],
 "class_ogre_1_1_compositor_manager.html":[5,0,1,12],
-"class_ogre_1_1_compositor_manager.html#a14161d8b081fa94f9caae3a0473d08db":[5,0,1,12,25],
-"class_ogre_1_1_compositor_manager.html#a19e9fac87ffda184125510157b6d48ff":[5,0,1,12,18],
-"class_ogre_1_1_compositor_manager.html#a1ac07452c980fbcb7445346b4ff329bf":[5,0,1,12,15],
-"class_ogre_1_1_compositor_manager.html#a25c528930841cdf825aa359850bd7788":[5,0,1,12,19],
-"class_ogre_1_1_compositor_manager.html#a31073e01284c78ef183f8eba087aa9c1":[5,0,1,12,22],
-"class_ogre_1_1_compositor_manager.html#a31474f0e4d6485437c1cb856923d4499":[5,0,1,12,24],
+"class_ogre_1_1_compositor_manager.html#a13a596ef6964a68dc25e9858b2201d26":[5,0,1,12,14],
+"class_ogre_1_1_compositor_manager.html#a14161d8b081fa94f9caae3a0473d08db":[5,0,1,12,26],
+"class_ogre_1_1_compositor_manager.html#a19e9fac87ffda184125510157b6d48ff":[5,0,1,12,19],
+"class_ogre_1_1_compositor_manager.html#a1ac07452c980fbcb7445346b4ff329bf":[5,0,1,12,16],
+"class_ogre_1_1_compositor_manager.html#a25c528930841cdf825aa359850bd7788":[5,0,1,12,20],
+"class_ogre_1_1_compositor_manager.html#a31073e01284c78ef183f8eba087aa9c1":[5,0,1,12,23],
+"class_ogre_1_1_compositor_manager.html#a31474f0e4d6485437c1cb856923d4499":[5,0,1,12,25],
 "class_ogre_1_1_compositor_manager.html#a40c9604cabf06d767110f4c2d73cf65d":[5,0,1,12,10],
 "class_ogre_1_1_compositor_manager.html#a40feb1956c7edd68fd65835a44db84b0":[5,0,1,12,12],
 "class_ogre_1_1_compositor_manager.html#a412c661642f90327cc59eea475194b81":[5,0,1,12,0],
-"class_ogre_1_1_compositor_manager.html#a58f71f164aff7d56b1f2c563522b651a":[5,0,1,12,26],
+"class_ogre_1_1_compositor_manager.html#a58f71f164aff7d56b1f2c563522b651a":[5,0,1,12,27],
 "class_ogre_1_1_compositor_manager.html#a5cc7bae199f7984d34f725c7d0d255fb":[5,0,1,12,13],
 "class_ogre_1_1_compositor_manager.html#a5d3c650de250cd3cb66484730fd4f95a":[5,0,1,12,7],
 "class_ogre_1_1_compositor_manager.html#a774da533de0e9dc7263551a37136a2c6":[5,0,1,12,4],
-"class_ogre_1_1_compositor_manager.html#a7abff0df9bc7cdd96cb730f8baad7f04":[5,0,1,12,21],
+"class_ogre_1_1_compositor_manager.html#a7abff0df9bc7cdd96cb730f8baad7f04":[5,0,1,12,22],
 "class_ogre_1_1_compositor_manager.html#a95a06faa7dac1be13f90b723ed8fa625":[5,0,1,12,9],
-"class_ogre_1_1_compositor_manager.html#a9c7d4168d56868599badb2789d54157c":[5,0,1,12,16],
+"class_ogre_1_1_compositor_manager.html#a9c7d4168d56868599badb2789d54157c":[5,0,1,12,17],
 "class_ogre_1_1_compositor_manager.html#aa4fc21a9b8393b670c732dfbfa0e7577":[5,0,1,12,6],
-"class_ogre_1_1_compositor_manager.html#aa7da6f02251d1e14ee50dcb1591e391c":[5,0,1,12,17],
+"class_ogre_1_1_compositor_manager.html#aa7da6f02251d1e14ee50dcb1591e391c":[5,0,1,12,18],
 "class_ogre_1_1_compositor_manager.html#aa8e6e8df0d1413256a0b961fe929eab7":[5,0,1,12,3],
 "class_ogre_1_1_compositor_manager.html#aa9897c6f8287aee48aa96e7ffcf29de5":[5,0,1,12,5],
 "class_ogre_1_1_compositor_manager.html#ab3f3a6e9ea6abe6edbb428613a8b866a":[5,0,1,12,8],
 "class_ogre_1_1_compositor_manager.html#abc22280b859b4f57bb71a63374c36032":[5,0,1,12,11],
-"class_ogre_1_1_compositor_manager.html#ac6daf1c536921b05c05a172a6a2b466f":[5,0,1,12,14],
+"class_ogre_1_1_compositor_manager.html#ac6daf1c536921b05c05a172a6a2b466f":[5,0,1,12,15],
 "class_ogre_1_1_compositor_manager.html#ac758255395ad3b00bea001aa0aaf88d6":[5,0,1,12,2],
-"class_ogre_1_1_compositor_manager.html#ad41f67cec0ec695f3e29263de4003d2f":[5,0,1,12,23],
-"class_ogre_1_1_compositor_manager.html#ae9b8ca4c2a51c0720bb31393d20fe7c9":[5,0,1,12,20],
+"class_ogre_1_1_compositor_manager.html#ad41f67cec0ec695f3e29263de4003d2f":[5,0,1,12,24],
+"class_ogre_1_1_compositor_manager.html#ae9b8ca4c2a51c0720bb31393d20fe7c9":[5,0,1,12,21],
 "class_ogre_1_1_compositor_manager.html#aeb2dde02f0631082a73fafcff189f3d7":[5,0,1,12,1],
 "class_ogre_1_1_config_dialog.html":[5,0,2,6],
 "class_ogre_1_1_config_dialog.html#a845325a51753f951ee75c29b1ad8aa85":[5,0,2,6,0],
@@ -215,39 +249,5 @@ var NAVTREEINDEX10 =
 "class_ogre_1_1_convex_body.html#adfbbf661c51787908f15b76fc3d55244":[5,0,6,4,15],
 "class_ogre_1_1_convex_body.html#ae9792f9784f57a75d89a8aecb9ee2f58":[5,0,6,4,3],
 "class_ogre_1_1_convex_body.html#af344427771b8ee0bde94a04e68cf4b77":[5,0,6,4,5],
-"class_ogre_1_1_convex_body.html#af5fb91ac168eec8056adb7b2677523e1":[5,0,6,4,6],
-"class_ogre_1_1_create_compositor_script_compiler_event.html":[5,0,10,3],
-"class_ogre_1_1_create_compositor_script_compiler_event.html#a1b8f501137d19fd80f68007ff788fce8":[5,0,10,3,1],
-"class_ogre_1_1_create_compositor_script_compiler_event.html#a9f07c294aeb33e46ef06d758add7d584":[5,0,10,3,2],
-"class_ogre_1_1_create_compositor_script_compiler_event.html#aa1246f8c43e041010598e736c293948e":[5,0,10,3,0],
-"class_ogre_1_1_create_compositor_script_compiler_event.html#ab81debbe356569675c115026c16642eb":[5,0,10,3,3],
-"class_ogre_1_1_create_compositor_script_compiler_event.html#aef2a0596e638e688e695dafc3d5d1521":[5,0,10,3,4],
-"class_ogre_1_1_create_gpu_program_script_compiler_event.html":[5,0,10,4],
-"class_ogre_1_1_create_gpu_program_script_compiler_event.html#a2bfe09f8c1632afaf9894bd2331c5db7":[5,0,10,4,3],
-"class_ogre_1_1_create_gpu_program_script_compiler_event.html#a44a1dbc63e7673519dbf1b666102cd34":[5,0,10,4,7],
-"class_ogre_1_1_create_gpu_program_script_compiler_event.html#a53c8dd264143054dbf29a79107dedca1":[5,0,10,4,0],
-"class_ogre_1_1_create_gpu_program_script_compiler_event.html#a5bb7ae1ec25eda3119af6e92ca9bdf39":[5,0,10,4,2],
-"class_ogre_1_1_create_gpu_program_script_compiler_event.html#a7b906375e72b00b76b9ac211716ec9ec":[5,0,10,4,6],
-"class_ogre_1_1_create_gpu_program_script_compiler_event.html#a89985079a4a8348d9c5fd133fb752dec":[5,0,10,4,1],
-"class_ogre_1_1_create_gpu_program_script_compiler_event.html#a8afd68b508b35b52c60c256e846b24ff":[5,0,10,4,4],
-"class_ogre_1_1_create_gpu_program_script_compiler_event.html#aa10432fb214d5d1304b8c12bbfcdbc53":[5,0,10,4,5],
-"class_ogre_1_1_create_gpu_shared_parameters_script_compiler_event.html":[5,0,10,5],
-"class_ogre_1_1_create_gpu_shared_parameters_script_compiler_event.html#a1b7cbae6225a03537eb8d86019019e68":[5,0,10,5,2],
-"class_ogre_1_1_create_gpu_shared_parameters_script_compiler_event.html#a498eb4924486fccbd9c2e83cdc205b51":[5,0,10,5,0],
-"class_ogre_1_1_create_gpu_shared_parameters_script_compiler_event.html#a896fe40542b24eeb5814bc371c5f2cb0":[5,0,10,5,4],
-"class_ogre_1_1_create_gpu_shared_parameters_script_compiler_event.html#a983cf04921ea813dccff75ccaf5f7005":[5,0,10,5,3],
-"class_ogre_1_1_create_gpu_shared_parameters_script_compiler_event.html#ac68ed9e815579490856c2e722e60f630":[5,0,10,5,1],
-"class_ogre_1_1_create_material_script_compiler_event.html":[5,0,10,6],
-"class_ogre_1_1_create_material_script_compiler_event.html#a10dbdf2ae2dac913c552c799e8878064":[5,0,10,6,0],
-"class_ogre_1_1_create_material_script_compiler_event.html#a1d11e1b36c4e3020a17579c2a7dd9cce":[5,0,10,6,2],
-"class_ogre_1_1_create_material_script_compiler_event.html#a45a175db818b216a1c2bcec9394557c9":[5,0,10,6,1],
-"class_ogre_1_1_create_material_script_compiler_event.html#a99ee0b5555a50c2786826902f73d7173":[5,0,10,6,4],
-"class_ogre_1_1_create_material_script_compiler_event.html#af9f939d7217bf645405e2106df7a6612":[5,0,10,6,3],
-"class_ogre_1_1_create_particle_system_script_compiler_event.html":[5,0,10,7],
-"class_ogre_1_1_create_particle_system_script_compiler_event.html#a35db50fc079ef40ae98a0789afdfca5e":[5,0,10,7,4],
-"class_ogre_1_1_create_particle_system_script_compiler_event.html#a7a252f8660b61c20d31773bbfc1d8412":[5,0,10,7,1],
-"class_ogre_1_1_create_particle_system_script_compiler_event.html#a828774193e4f2704a068fd0582becfae":[5,0,10,7,2],
-"class_ogre_1_1_create_particle_system_script_compiler_event.html#ac25d4cbd99b13a92efa1ec773b4aead8":[5,0,10,7,3],
-"class_ogre_1_1_create_particle_system_script_compiler_event.html#ae5d353f53c585c185969c67c01b80890":[5,0,10,7,0],
-"class_ogre_1_1_custom_composition_pass.html":[5,0,1,13]
+"class_ogre_1_1_convex_body.html#af5fb91ac168eec8056adb7b2677523e1":[5,0,6,4,6]
 };
