@@ -1,5 +1,19 @@
 var NAVTREEINDEX18 =
 {
+"class_ogre_1_1_image.html#ad90b11682c53f7fe2c99bfd3bc06c5ac":[5,0,3,0,42],
+"class_ogre_1_1_image.html#ad933a75945dd8573925bf707d9035a6b":[5,0,3,0,19],
+"class_ogre_1_1_image.html#adefc5ec16de7ea09fca1c5bbe6782a4c":[5,0,3,0,40],
+"class_ogre_1_1_image.html#ae2db6b18aae0389177f297e9c6bee8a7":[5,0,3,0,30],
+"class_ogre_1_1_image.html#aed8c00129e855863b05ee8ea835ba338":[5,0,3,0,31],
+"class_ogre_1_1_image.html#af03348ae68a6b5467a2e3d131f6571f2":[5,0,3,0,4],
+"class_ogre_1_1_image.html#af3433519ee4aa9a9141b67657810b110":[5,0,3,0,37],
+"class_ogre_1_1_image.html#af65aa7216f9f9ecce4158ffd20b9cea6":[5,0,3,0,38],
+"class_ogre_1_1_image_codec.html":[5,0,3,1],
+"class_ogre_1_1_import_abstract_node.html":[5,0,10,8],
+"class_ogre_1_1_import_abstract_node.html#a2979096d9e6ff882bce5a9e6bbecbd18":[5,0,10,8,3],
+"class_ogre_1_1_import_abstract_node.html#a44e8ff802eb8c81bfbd9e8805781e4e2":[5,0,10,8,0],
+"class_ogre_1_1_import_abstract_node.html#a9aaac988ee27c8af36de204eaa0f8f99":[5,0,10,8,1],
+"class_ogre_1_1_import_abstract_node.html#ab952f51e379ca1709d4d09d9856698d5":[5,0,10,8,2],
 "class_ogre_1_1_import_abstract_node.html#abf7e3cadcd65283bae356cc5dde84826":[5,0,10,8,4],
 "class_ogre_1_1_index_data.html":[5,0,7,16],
 "class_ogre_1_1_index_data.html#a0c19f7fc00c66266fd0d7fe671733112":[5,0,7,16,3],
@@ -129,10 +143,10 @@ var NAVTREEINDEX18 =
 "class_ogre_1_1_light.html#a8ae9c19d6fd9d0d3a961225abd29126e":[5,0,9,23,10],
 "class_ogre_1_1_light.html#a8be55b8ecc3c79532711429fc8a5d36a":[5,0,9,23,59],
 "class_ogre_1_1_light.html#a8dfbfef136e815bd6c8d2850b5364c44":[5,0,9,23,55],
-"class_ogre_1_1_light.html#a8ef06bd9c2e7113461c50c83c5f09fe9":[5,0,9,23,27],
 "class_ogre_1_1_light.html#a8ef572fd5d20b366328cbdb0eb71b4a0":[5,0,9,23,6],
 "class_ogre_1_1_light.html#a91a8c7867631ecda45eb934bfaf0aff1":[5,0,9,23,64],
 "class_ogre_1_1_light.html#a93ac8bb5fd365c2469c96db4b676a955":[5,0,9,23,51],
+"class_ogre_1_1_light.html#aa246bc8a76382d6a4e9d2fb92f77d4fc":[5,0,9,23,27],
 "class_ogre_1_1_light.html#aa41bd29b2f37800f618cdb1eb73ef2c7":[5,0,9,23,24],
 "class_ogre_1_1_light.html#aa654189e8307f6d173bdc657c4005674":[5,0,9,23,73],
 "class_ogre_1_1_light.html#aa9c6df55eafb28a2a0bab287bc9596f7":[5,0,9,23,22],
@@ -235,19 +249,5 @@ var NAVTREEINDEX18 =
 "class_ogre_1_1_lod_collapse_cost_profiler.html#a7ca1ac32f2f5efd735204f732f15037d":[6,0,1,240,3],
 "class_ogre_1_1_lod_collapse_cost_profiler.html#a7ca1ac32f2f5efd735204f732f15037d":[7,0,0,240,3],
 "class_ogre_1_1_lod_collapse_cost_profiler.html#ab0100fde2b3953dd389fe578a413f4c9":[6,0,1,240,1],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#ab0100fde2b3953dd389fe578a413f4c9":[7,0,0,240,1],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#ae8a2d2cf140fa05e2132f8d8cfe76d2a":[6,0,1,240,2],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#ae8a2d2cf140fa05e2132f8d8cfe76d2a":[7,0,0,240,2],
-"class_ogre_1_1_lod_collapse_cost_quadric.html":[6,0,1,241],
-"class_ogre_1_1_lod_collapse_cost_quadric.html":[7,0,0,241],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#a36e8c2daebc2cb8013716485fc472fe0":[6,0,1,241,0],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#a36e8c2daebc2cb8013716485fc472fe0":[7,0,0,241,0],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#a5fd759d8f5be1763147fa547cc1c2223":[6,0,1,241,2],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#a5fd759d8f5be1763147fa547cc1c2223":[7,0,0,241,2],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#a6c5d7dbd0032ba9e5722ce7efa2a520e":[6,0,1,241,1],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#a6c5d7dbd0032ba9e5722ce7efa2a520e":[7,0,0,241,1],
-"class_ogre_1_1_lod_collapser.html":[5,1,2,1],
-"class_ogre_1_1_lod_collapser.html#a51d851d50ebcee4f77cff26f500ccce7":[5,1,2,1,0],
-"class_ogre_1_1_lod_collapser.html#a8a3dc7a3ba0d2777dd8656429540e8cd":[5,1,2,1,3],
-"class_ogre_1_1_lod_collapser.html#ab2c58971bcc0ecac574ac377b56f3c30":[5,1,2,1,2]
+"class_ogre_1_1_lod_collapse_cost_profiler.html#ab0100fde2b3953dd389fe578a413f4c9":[7,0,0,240,1]
 };
