@@ -1,5 +1,21 @@
 var NAVTREEINDEX34 =
 {
+"class_ogre_1_1_region_scene_query.html#aacf8e0e589c0573719d213c5f826247a":[5,0,9,37,2],
+"class_ogre_1_1_region_scene_query.html#abed5e4ec3f0f6606e740a5683a85abf0":[5,0,9,37,7],
+"class_ogre_1_1_region_scene_query.html#addb9bb97762d4b2e860789da8b9dd3b5":[5,0,9,37,0],
+"class_ogre_1_1_region_scene_query.html#af63d52b2d36e924f8757f6da2f48e597":[5,0,9,37,5],
+"class_ogre_1_1_render_object_listener.html":[6,0,1,405],
+"class_ogre_1_1_render_object_listener.html":[7,0,0,405],
+"class_ogre_1_1_render_object_listener.html#a5fc7de0f8ead61860e1125c539afd52b":[6,0,1,405,0],
+"class_ogre_1_1_render_object_listener.html#a5fc7de0f8ead61860e1125c539afd52b":[7,0,0,405,0],
+"class_ogre_1_1_render_object_listener.html#a99b1b17e89efbbce74756925a4acad38":[6,0,1,405,1],
+"class_ogre_1_1_render_object_listener.html#a99b1b17e89efbbce74756925a4acad38":[7,0,0,405,1],
+"class_ogre_1_1_render_operation.html":[5,0,7,21],
+"class_ogre_1_1_render_operation.html#a21998ad8a9cb134420158dc8e2663eac":[5,0,7,21,1],
+"class_ogre_1_1_render_operation.html#a306c2ed3599abab29a027325e3d6d721":[5,0,7,21,2],
+"class_ogre_1_1_render_operation.html#a6f6cbc81ef5f41d3a0357a40095aba33":[5,0,7,21,4],
+"class_ogre_1_1_render_operation.html#a7646ad7a394e7bb74aac8d55515f3975":[5,0,7,21,8],
+"class_ogre_1_1_render_operation.html#a880adde68db01dffcfac616de0ef1f45":[5,0,7,21,6],
 "class_ogre_1_1_render_operation.html#aa7e82691778b82e07e81f4fc9246326d":[5,0,7,21,5],
 "class_ogre_1_1_render_operation.html#ab8b780ec18ee4675e85f475b21f77c82":[5,0,7,21,0],
 "class_ogre_1_1_render_operation.html#ab8b780ec18ee4675e85f475b21f77c82a03451b001b2a90d8bc9234768aa1239b":[5,0,7,21,0,16],
@@ -233,21 +249,5 @@ var NAVTREEINDEX34 =
 "class_ogre_1_1_render_system.html#ad65f49ccce525d3753a38b75b4166f9e":[5,0,7,26,57],
 "class_ogre_1_1_render_system.html#ad8a5b37533d19a0248aad5b7620627d6":[5,0,7,26,30],
 "class_ogre_1_1_render_system.html#ada91bd7e7ceb832c4598596084f240ef":[5,0,7,26,112],
-"class_ogre_1_1_render_system.html#adbd05815a9a3207206eee39eccbf1d98":[5,0,7,26,77],
-"class_ogre_1_1_render_system.html#addfea71a41353277fa57585cda4d6627":[5,0,7,26,52],
-"class_ogre_1_1_render_system.html#adedbeb77d3def3967ee1a55c32d16a2b":[5,0,7,26,78],
-"class_ogre_1_1_render_system.html#ae667be14fe8ada14d3f246066e4efaf7":[5,0,7,26,73],
-"class_ogre_1_1_render_system.html#ae8144a770f5bbe9390928abf24d37b16":[5,0,7,26,89],
-"class_ogre_1_1_render_system.html#af065d694a866bedee81bcf01e1da55a2":[5,0,7,26,3],
-"class_ogre_1_1_render_system.html#af08c82c98dc70223223d3d72580561ce":[5,0,7,26,56],
-"class_ogre_1_1_render_system.html#af942e9e362a20277c177c062879fbd51":[5,0,7,26,98],
-"class_ogre_1_1_render_system.html#afc69e09f59064b79f3bfd4402617d07a":[5,0,7,26,12],
-"class_ogre_1_1_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7":[5,0,7,26,20],
-"class_ogre_1_1_render_system_1_1_listener.html":[5,0,7,26,0],
-"class_ogre_1_1_render_system_1_1_listener.html#a2ccefd2fe4eb8ca096e8ec7efbefc413":[5,0,7,26,0,0],
-"class_ogre_1_1_render_system_1_1_listener.html#a92f2b3702187d4893f0a28993510f759":[5,0,7,26,0,1],
-"class_ogre_1_1_render_system_1_1_listener.html#aafc262fea83eae3a360aeb16d1cc7ef9":[5,0,7,26,0,2],
-"class_ogre_1_1_render_system_capabilities.html":[5,0,7,27],
-"class_ogre_1_1_render_system_capabilities.html#a04d9002874f93e33c1c19b77981619b9":[5,0,7,27,1],
-"class_ogre_1_1_render_system_capabilities.html#a11ea4ae1018fa18e6192a0898251b5d1":[5,0,7,27,26]
+"class_ogre_1_1_render_system.html#adbd05815a9a3207206eee39eccbf1d98":[5,0,7,26,77]
 };
