@@ -1,37 +1,54 @@
 var NAVTREEINDEX38 =
 {
-"class_ogre_1_1_scene_manager.html#a4e166fc972e614490ab6164eda2be0e5":[5,0,9,39,240],
+"class_ogre_1_1_scene_manager.html#a3dce9a03ecad77d52ed0a8ef0e8b742c":[5,0,9,39,121],
+"class_ogre_1_1_scene_manager.html#a3e26531b08c7b9666ef1ecbd8568bbf8":[5,0,9,39,83],
+"class_ogre_1_1_scene_manager.html#a3f2c4ffe2ab173848c0cff67789d530e":[5,0,9,39,229],
+"class_ogre_1_1_scene_manager.html#a3ff36a4579bde7a0406752c7b64c89b9":[5,0,9,39,101],
+"class_ogre_1_1_scene_manager.html#a40f296de8599657b70b7072921cbaa16":[5,0,9,39,217],
+"class_ogre_1_1_scene_manager.html#a4222a0689cb56011c11faa9976192f11":[5,0,9,39,147],
+"class_ogre_1_1_scene_manager.html#a4249682ae2a69255ed225383d930aec1":[5,0,9,39,11],
+"class_ogre_1_1_scene_manager.html#a42817122ac0cbd7e3d95305681e661f0":[5,0,9,39,236],
+"class_ogre_1_1_scene_manager.html#a436a99beba747d203841471d90e5be2e":[5,0,9,39,193],
+"class_ogre_1_1_scene_manager.html#a43c5ca986d31852a89c6e2d06a025ee3":[5,0,9,39,239],
+"class_ogre_1_1_scene_manager.html#a45887375e05f0a6473c6265913ab9dae":[5,0,9,39,146],
+"class_ogre_1_1_scene_manager.html#a4718aa3c21b3569eb8772a1abb1af74d":[5,0,9,39,77],
+"class_ogre_1_1_scene_manager.html#a4893a4c8bb8dac7b40733a3a440cd806":[5,0,9,39,304],
+"class_ogre_1_1_scene_manager.html#a4a672aaeb3ede6c03e1b072d51e21b7a":[5,0,9,39,68],
+"class_ogre_1_1_scene_manager.html#a4b9ad74ecd97a52ed3ad567703d30de6":[5,0,9,39,75],
+"class_ogre_1_1_scene_manager.html#a4d94f9a8c710929d53faa1d76c8e5a96":[5,0,9,39,90],
+"class_ogre_1_1_scene_manager.html#a4e166fc972e614490ab6164eda2be0e5":[5,0,9,39,241],
 "class_ogre_1_1_scene_manager.html#a4f17d2305cd0fc3e177d9264b9beda52":[5,0,9,39,52],
-"class_ogre_1_1_scene_manager.html#a5004093c72a34c3d50f17c754a4dd572":[5,0,9,39,267],
+"class_ogre_1_1_scene_manager.html#a5004093c72a34c3d50f17c754a4dd572":[5,0,9,39,268],
 "class_ogre_1_1_scene_manager.html#a51db39cc4fa15b28086a1793d42fc827":[5,0,9,39,13],
 "class_ogre_1_1_scene_manager.html#a51db39cc4fa15b28086a1793d42fc827a0e1792a8ff0d3d19f121818e7028e846":[5,0,9,39,13,2],
 "class_ogre_1_1_scene_manager.html#a51db39cc4fa15b28086a1793d42fc827a8f99da7404ae8c16199dde8d34367b1a":[5,0,9,39,13,1],
 "class_ogre_1_1_scene_manager.html#a51db39cc4fa15b28086a1793d42fc827a8fd3e7fb8fab382a9d29e6e081ae556a":[5,0,9,39,13,0],
 "class_ogre_1_1_scene_manager.html#a53d1cf1fd4f032a10b4672f288322ddf":[5,0,9,39,169],
 "class_ogre_1_1_scene_manager.html#a552b50df0af56788957bd6a2650c58e3":[5,0,9,39,98],
-"class_ogre_1_1_scene_manager.html#a5579128d01a04448a96d6a2acc663a45":[5,0,9,39,264],
+"class_ogre_1_1_scene_manager.html#a5579128d01a04448a96d6a2acc663a45":[5,0,9,39,265],
 "class_ogre_1_1_scene_manager.html#a55d38f8da01e689b2d65e2b71ad9a9b0":[5,0,9,39,39],
 "class_ogre_1_1_scene_manager.html#a56487d9e9eed75314b5e4a10af78d487":[5,0,9,39,85],
-"class_ogre_1_1_scene_manager.html#a5680c250fb35ab999e0d5d10b597216b":[5,0,9,39,263],
+"class_ogre_1_1_scene_manager.html#a5680c250fb35ab999e0d5d10b597216b":[5,0,9,39,264],
 "class_ogre_1_1_scene_manager.html#a56882cf297909d38cb48b037dcbbfbd5":[5,0,9,39,64],
 "class_ogre_1_1_scene_manager.html#a56f24ca2f117f45d6078e54d63de235c":[5,0,9,39,47],
-"class_ogre_1_1_scene_manager.html#a572ba24b3243aafc7ccc74598b018eeb":[5,0,9,39,282],
+"class_ogre_1_1_scene_manager.html#a572ba24b3243aafc7ccc74598b018eeb":[5,0,9,39,283],
 "class_ogre_1_1_scene_manager.html#a57bca9b27045ef0acc9d6cfe5f2668dd":[5,0,9,39,61],
 "class_ogre_1_1_scene_manager.html#a589b3eb241b2531097d7ed67e716d420":[5,0,9,39,58],
 "class_ogre_1_1_scene_manager.html#a58e3a4d5853bfa8a182cbc487c6f61e6":[5,0,9,39,95],
 "class_ogre_1_1_scene_manager.html#a59347bd0277c99dc2291965053aed4c6":[5,0,9,39,70],
+"class_ogre_1_1_scene_manager.html#a5c6041038ec4b9b10681c116731ea864":[5,0,9,39,223],
 "class_ogre_1_1_scene_manager.html#a5c9816798bda78389efc4f071051c739":[5,0,9,39,17],
 "class_ogre_1_1_scene_manager.html#a5d045c10d23adb73e03751505beb346a":[5,0,9,39,25],
 "class_ogre_1_1_scene_manager.html#a5dce576ae8d38b4ed712991115cf1067":[5,0,9,39,215],
-"class_ogre_1_1_scene_manager.html#a5e3389a02ae12fc67f999bf16495010b":[5,0,9,39,225],
+"class_ogre_1_1_scene_manager.html#a5e3389a02ae12fc67f999bf16495010b":[5,0,9,39,226],
 "class_ogre_1_1_scene_manager.html#a5e629af63f5f273a69aa9cf1e9bbceb7":[5,0,9,39,131],
 "class_ogre_1_1_scene_manager.html#a5f5320728d8846ebe7ced3b972d37520":[5,0,9,39,67],
-"class_ogre_1_1_scene_manager.html#a5fcc14bc6160a096212b08136fd18bc0":[5,0,9,39,270],
+"class_ogre_1_1_scene_manager.html#a5fcc14bc6160a096212b08136fd18bc0":[5,0,9,39,271],
 "class_ogre_1_1_scene_manager.html#a603589528618542a181314d90cb01985":[5,0,9,39,156],
-"class_ogre_1_1_scene_manager.html#a6336349899e883a51d7446ef4cc3d9df":[5,0,9,39,298],
+"class_ogre_1_1_scene_manager.html#a6336349899e883a51d7446ef4cc3d9df":[5,0,9,39,299],
 "class_ogre_1_1_scene_manager.html#a65a4957bcb2a0fbffcb8ef37c1f6c6b1":[5,0,9,39,201],
-"class_ogre_1_1_scene_manager.html#a66125a97e2d4722031dd636f7229569c":[5,0,9,39,288],
-"class_ogre_1_1_scene_manager.html#a69310c322ea5f58d9c38c13a971f8125":[5,0,9,39,244],
+"class_ogre_1_1_scene_manager.html#a66125a97e2d4722031dd636f7229569c":[5,0,9,39,289],
+"class_ogre_1_1_scene_manager.html#a69310c322ea5f58d9c38c13a971f8125":[5,0,9,39,245],
 "class_ogre_1_1_scene_manager.html#a69d6cb870736cd52b9ca48986e2e442b":[5,0,9,39,204],
 "class_ogre_1_1_scene_manager.html#a6a518d9bb5e39500df870f538be7a939":[5,0,9,39,124],
 "class_ogre_1_1_scene_manager.html#a6aa3039230bf91b09b8587dba0c482c6":[5,0,9,39,14],
@@ -49,20 +66,20 @@ var NAVTREEINDEX38 =
 "class_ogre_1_1_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aa8e038bbc4c20e0b165a93456aceccac1":[5,0,9,39,12,4],
 "class_ogre_1_1_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aabf31f2e39287202aaf433b4f4eca2ba9":[5,0,9,39,12,0],
 "class_ogre_1_1_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aafa4ca767da4b4d17cb62d1f68a5dd614":[5,0,9,39,12,5],
-"class_ogre_1_1_scene_manager.html#a6efbc50e4ab15a4436cac712e049e79e":[5,0,9,39,234],
+"class_ogre_1_1_scene_manager.html#a6efbc50e4ab15a4436cac712e049e79e":[5,0,9,39,235],
 "class_ogre_1_1_scene_manager.html#a70f86c8feca6c2b5cf140df244cf8ac5":[5,0,9,39,122],
-"class_ogre_1_1_scene_manager.html#a70f8eddf9b8617783fb7d0995b985a9a":[5,0,9,39,232],
+"class_ogre_1_1_scene_manager.html#a70f8eddf9b8617783fb7d0995b985a9a":[5,0,9,39,233],
 "class_ogre_1_1_scene_manager.html#a710197d0688d6b3876984d595bdfa6ba":[5,0,9,39,29],
-"class_ogre_1_1_scene_manager.html#a7179987953e8b7889610ab469637bd93":[5,0,9,39,281],
+"class_ogre_1_1_scene_manager.html#a7179987953e8b7889610ab469637bd93":[5,0,9,39,282],
 "class_ogre_1_1_scene_manager.html#a723da9119c26f5022e3a2818611e9aa0":[5,0,9,39,45],
-"class_ogre_1_1_scene_manager.html#a72e39912a34617ffa0455f859ec438c3":[5,0,9,39,310],
+"class_ogre_1_1_scene_manager.html#a72e39912a34617ffa0455f859ec438c3":[5,0,9,39,311],
 "class_ogre_1_1_scene_manager.html#a72e8efd88543fbc1c5ef1ce91b2cbd8a":[5,0,9,39,197],
 "class_ogre_1_1_scene_manager.html#a7399c836bf57186f171f4eb456c7fe4d":[5,0,9,39,36],
 "class_ogre_1_1_scene_manager.html#a7924f5a9ac983d29a5876d633f8a971d":[5,0,9,39,55],
 "class_ogre_1_1_scene_manager.html#a794e03ea25dd798346414c1dba31337d":[5,0,9,39,18],
 "class_ogre_1_1_scene_manager.html#a79cd2c00addb8bb51943e0080d92c633":[5,0,9,39,137],
 "class_ogre_1_1_scene_manager.html#a79dcd5f1790076ec46cf1e400ea906e4":[5,0,9,39,88],
-"class_ogre_1_1_scene_manager.html#a7a825394e34b46ac32c89ca6ed97d49e":[5,0,9,39,226],
+"class_ogre_1_1_scene_manager.html#a7a825394e34b46ac32c89ca6ed97d49e":[5,0,9,39,227],
 "class_ogre_1_1_scene_manager.html#a7b0f316813a3291964abd93ca2372f3d":[5,0,9,39,59],
 "class_ogre_1_1_scene_manager.html#a7b12c8a965b7dd03f6b07d8acfa74079":[5,0,9,39,203],
 "class_ogre_1_1_scene_manager.html#a7b33443d4ec80ecba17eba8dab4491a2":[5,0,9,39,165],
@@ -75,78 +92,77 @@ var NAVTREEINDEX38 =
 "class_ogre_1_1_scene_manager.html#a7fc3ad85f4ca3e3a07b0c94950debeec":[5,0,9,39,177],
 "class_ogre_1_1_scene_manager.html#a80690a9450039852c9dc56a07688eb8b":[5,0,9,39,179],
 "class_ogre_1_1_scene_manager.html#a81238e49e69e53ccbc650413410f3f92":[5,0,9,39,202],
-"class_ogre_1_1_scene_manager.html#a813346e505716ae5d24f714cfc4a5069":[5,0,9,39,54],
 "class_ogre_1_1_scene_manager.html#a81e0a45199422dd2e4f4ffd49fde482e":[5,0,9,39,73],
 "class_ogre_1_1_scene_manager.html#a829e11cca3dfaf8142578930e1da6844":[5,0,9,39,34],
-"class_ogre_1_1_scene_manager.html#a82ee334ba3818ff766463a74bfbf985c":[5,0,9,39,292],
+"class_ogre_1_1_scene_manager.html#a82ee334ba3818ff766463a74bfbf985c":[5,0,9,39,293],
 "class_ogre_1_1_scene_manager.html#a851077fcf56225e174e0f0a52230061c":[5,0,9,39,126],
-"class_ogre_1_1_scene_manager.html#a85c3a0d9755dfdfa841ec1383b20687c":[5,0,9,39,230],
+"class_ogre_1_1_scene_manager.html#a85c3a0d9755dfdfa841ec1383b20687c":[5,0,9,39,231],
 "class_ogre_1_1_scene_manager.html#a863ba56ae571446bb0807aa7e7204d1d":[5,0,9,39,167],
 "class_ogre_1_1_scene_manager.html#a864ef16daa56292b5e1e7661dc6f5f63":[5,0,9,39,152],
 "class_ogre_1_1_scene_manager.html#a87bb32dcfef86f5d04495ead956ad7e4":[5,0,9,39,166],
-"class_ogre_1_1_scene_manager.html#a89d5a39615a8edb5923cef433aba210d":[5,0,9,39,246],
-"class_ogre_1_1_scene_manager.html#a89f2ca5ef5c9ba9856fdfcd0fadb0742":[5,0,9,39,257],
+"class_ogre_1_1_scene_manager.html#a89d5a39615a8edb5923cef433aba210d":[5,0,9,39,247],
+"class_ogre_1_1_scene_manager.html#a89f2ca5ef5c9ba9856fdfcd0fadb0742":[5,0,9,39,258],
 "class_ogre_1_1_scene_manager.html#a8af3e6766eb128c8a8c02aab822e87fc":[5,0,9,39,210],
 "class_ogre_1_1_scene_manager.html#a8c46aaf43efdf676ea590bbec79b514c":[5,0,9,39,175],
-"class_ogre_1_1_scene_manager.html#a8cc2d2f9cee748c6f1c3ade359a35b7b":[5,0,9,39,254],
-"class_ogre_1_1_scene_manager.html#a8cd474a0bb93c6fa0e4439a5a7d11c63":[5,0,9,39,273],
+"class_ogre_1_1_scene_manager.html#a8cc2d2f9cee748c6f1c3ade359a35b7b":[5,0,9,39,255],
+"class_ogre_1_1_scene_manager.html#a8cd474a0bb93c6fa0e4439a5a7d11c63":[5,0,9,39,274],
 "class_ogre_1_1_scene_manager.html#a8d29d1e2d954090ce2fba768b7f30c02":[5,0,9,39,22],
-"class_ogre_1_1_scene_manager.html#a8d613edec86ef5bc9e4f36b8be47bd92":[5,0,9,39,253],
+"class_ogre_1_1_scene_manager.html#a8d613edec86ef5bc9e4f36b8be47bd92":[5,0,9,39,254],
 "class_ogre_1_1_scene_manager.html#a8db7412fbb04789eb885c4d503614c0d":[5,0,9,39,71],
 "class_ogre_1_1_scene_manager.html#a8ff7f09f3bc6a63e9c515187d3630733":[5,0,9,39,102],
-"class_ogre_1_1_scene_manager.html#a91a7ddeaa86b14ea4da9b33fad388ea8":[5,0,9,39,304],
-"class_ogre_1_1_scene_manager.html#a91dee910ef9412d09800e11b4c5f569c":[5,0,9,39,301],
-"class_ogre_1_1_scene_manager.html#a9226149b4f9745ff57f978014a9fda48":[5,0,9,39,277],
-"class_ogre_1_1_scene_manager.html#a92949801ae19aa32c11329e43ad32555":[5,0,9,39,265],
-"class_ogre_1_1_scene_manager.html#a92b9b85e83300438d40feed407285207":[5,0,9,39,286],
+"class_ogre_1_1_scene_manager.html#a91a7ddeaa86b14ea4da9b33fad388ea8":[5,0,9,39,305],
+"class_ogre_1_1_scene_manager.html#a91dee910ef9412d09800e11b4c5f569c":[5,0,9,39,302],
+"class_ogre_1_1_scene_manager.html#a9226149b4f9745ff57f978014a9fda48":[5,0,9,39,278],
+"class_ogre_1_1_scene_manager.html#a92949801ae19aa32c11329e43ad32555":[5,0,9,39,266],
+"class_ogre_1_1_scene_manager.html#a92b9b85e83300438d40feed407285207":[5,0,9,39,287],
 "class_ogre_1_1_scene_manager.html#a95ae7048e7f5d3ffabf6d8acbcf12a0d":[5,0,9,39,205],
-"class_ogre_1_1_scene_manager.html#a95b8dfba2dd4ed9b62dfef6fb6baf2b7":[5,0,9,39,280],
-"class_ogre_1_1_scene_manager.html#a95cd8ff86a7178c2e37b2fcb485f64fa":[5,0,9,39,222],
-"class_ogre_1_1_scene_manager.html#a974ac50bee0284e4bf69dcffa836c11f":[5,0,9,39,250],
-"class_ogre_1_1_scene_manager.html#a97a7f01d29c2eabe0843d966ab9601e3":[5,0,9,39,289],
+"class_ogre_1_1_scene_manager.html#a95b8dfba2dd4ed9b62dfef6fb6baf2b7":[5,0,9,39,281],
+"class_ogre_1_1_scene_manager.html#a974ac50bee0284e4bf69dcffa836c11f":[5,0,9,39,251],
+"class_ogre_1_1_scene_manager.html#a97a7f01d29c2eabe0843d966ab9601e3":[5,0,9,39,290],
 "class_ogre_1_1_scene_manager.html#a97f0a2a4c7992b7c37f704483f3a9166":[5,0,9,39,183],
-"class_ogre_1_1_scene_manager.html#a981ad410d5a077bb64938685e10fcee0":[5,0,9,39,290],
+"class_ogre_1_1_scene_manager.html#a981ad410d5a077bb64938685e10fcee0":[5,0,9,39,291],
 "class_ogre_1_1_scene_manager.html#a98bcdc55bd7cd845abf297100d3842a8":[5,0,9,39,171],
-"class_ogre_1_1_scene_manager.html#a99397cd65e23402e63966ff006f1ed6e":[5,0,9,39,269],
+"class_ogre_1_1_scene_manager.html#a99397cd65e23402e63966ff006f1ed6e":[5,0,9,39,270],
 "class_ogre_1_1_scene_manager.html#a9a394daa05374d05e4e378f540418c1f":[5,0,9,39,24],
-"class_ogre_1_1_scene_manager.html#a9a5c7191febaebc65eb605202c0062cb":[5,0,9,39,249],
+"class_ogre_1_1_scene_manager.html#a9a5c7191febaebc65eb605202c0062cb":[5,0,9,39,250],
 "class_ogre_1_1_scene_manager.html#a9b10b7fef2893e75acc083415df70446":[5,0,9,39,21],
-"class_ogre_1_1_scene_manager.html#a9b4c5bd6f47373ca69a397edb49f3520":[5,0,9,39,245],
+"class_ogre_1_1_scene_manager.html#a9b4c5bd6f47373ca69a397edb49f3520":[5,0,9,39,246],
 "class_ogre_1_1_scene_manager.html#a9b7ebcecf64452f59211f45d4ec33576":[5,0,9,39,109],
-"class_ogre_1_1_scene_manager.html#a9c2c49f7ecf09c146944d37727d58a2e":[5,0,9,39,260],
+"class_ogre_1_1_scene_manager.html#a9c28c0635389f53023a58304597fb2b0":[5,0,9,39,54],
+"class_ogre_1_1_scene_manager.html#a9c2c49f7ecf09c146944d37727d58a2e":[5,0,9,39,261],
 "class_ogre_1_1_scene_manager.html#a9d05b4611701aac416246a876d29c740":[5,0,9,39,213],
 "class_ogre_1_1_scene_manager.html#a9d64b8d561a3d6d7886a62209c834065":[5,0,9,39,208],
 "class_ogre_1_1_scene_manager.html#a9e1b6ae2ee342000f96a842a164ddfe2":[5,0,9,39,120],
-"class_ogre_1_1_scene_manager.html#a9f1d305989a47813acb2300c208ce603":[5,0,9,39,297],
-"class_ogre_1_1_scene_manager.html#aa0adfbc6f313be8895a9f38872c76eaf":[5,0,9,39,317],
-"class_ogre_1_1_scene_manager.html#aa1298c907d72f01f3510876d4597ed37":[5,0,9,39,275],
-"class_ogre_1_1_scene_manager.html#aa15b95a642dd9553498cba260ca160d8":[5,0,9,39,279],
-"class_ogre_1_1_scene_manager.html#aa22c0af6835b4a0524b4122756cdd93c":[5,0,9,39,243],
-"class_ogre_1_1_scene_manager.html#aa26b5c8c1d5094b5a09f1794dc834caf":[5,0,9,39,248],
+"class_ogre_1_1_scene_manager.html#a9f1d305989a47813acb2300c208ce603":[5,0,9,39,298],
+"class_ogre_1_1_scene_manager.html#aa0adfbc6f313be8895a9f38872c76eaf":[5,0,9,39,318],
+"class_ogre_1_1_scene_manager.html#aa1298c907d72f01f3510876d4597ed37":[5,0,9,39,276],
+"class_ogre_1_1_scene_manager.html#aa15b95a642dd9553498cba260ca160d8":[5,0,9,39,280],
+"class_ogre_1_1_scene_manager.html#aa22c0af6835b4a0524b4122756cdd93c":[5,0,9,39,244],
+"class_ogre_1_1_scene_manager.html#aa26b5c8c1d5094b5a09f1794dc834caf":[5,0,9,39,249],
 "class_ogre_1_1_scene_manager.html#aa316e7d1a4d80e75940246ccb260bcca":[5,0,9,39,159],
 "class_ogre_1_1_scene_manager.html#aa44ff5a2d2a8985b7c6d2296e7fa5ffa":[5,0,9,39,150],
 "class_ogre_1_1_scene_manager.html#aa4e86291c054d59c1312c10322e6bc55":[5,0,9,39,199],
-"class_ogre_1_1_scene_manager.html#aa55e7f4482a2860c6378d97d8b5dfb57":[5,0,9,39,223],
+"class_ogre_1_1_scene_manager.html#aa55e7f4482a2860c6378d97d8b5dfb57":[5,0,9,39,224],
 "class_ogre_1_1_scene_manager.html#aa5b2047b5740b691b0e636d57f2dba7e":[5,0,9,39,105],
 "class_ogre_1_1_scene_manager.html#aa613e5ffb08b95a90644a61ac10c9b5c":[5,0,9,39,53],
-"class_ogre_1_1_scene_manager.html#aaa36e203e1ba3eeab880e4c51a51efae":[5,0,9,39,311],
-"class_ogre_1_1_scene_manager.html#aaa72eaf9861531687d7bb2a4cc989f42":[5,0,9,39,312],
+"class_ogre_1_1_scene_manager.html#aaa36e203e1ba3eeab880e4c51a51efae":[5,0,9,39,312],
+"class_ogre_1_1_scene_manager.html#aaa72eaf9861531687d7bb2a4cc989f42":[5,0,9,39,313],
 "class_ogre_1_1_scene_manager.html#aabb31522f577a7ebc1ecade779d056c9":[5,0,9,39,60],
 "class_ogre_1_1_scene_manager.html#aac4d1620c2d2d9ab5c78a3730eabc180":[5,0,9,39,168],
 "class_ogre_1_1_scene_manager.html#aacb4f28f6f9ae731040c9d664da7d6ce":[5,0,9,39,48],
 "class_ogre_1_1_scene_manager.html#aad530a7588b2544eba74370c041dfbe5":[5,0,9,39,161],
 "class_ogre_1_1_scene_manager.html#aad88733248aafaec3c399e3fb3b69628":[5,0,9,39,99],
 "class_ogre_1_1_scene_manager.html#aaf563008369ba9853dd3b862ab2cb0ab":[5,0,9,39,187],
-"class_ogre_1_1_scene_manager.html#ab0a1beb3ad46d39d89d0338f2ec21558":[5,0,9,39,291],
-"class_ogre_1_1_scene_manager.html#ab0cfa0bac914e025fbf2ed64f6b6ef5d":[5,0,9,39,266],
+"class_ogre_1_1_scene_manager.html#ab0a1beb3ad46d39d89d0338f2ec21558":[5,0,9,39,292],
+"class_ogre_1_1_scene_manager.html#ab0cfa0bac914e025fbf2ed64f6b6ef5d":[5,0,9,39,267],
 "class_ogre_1_1_scene_manager.html#ab28450738168fe330709ad0d090df6b5":[5,0,9,39,174],
 "class_ogre_1_1_scene_manager.html#ab2bd35627468a27a8e52a30cc364cc82":[5,0,9,39,142],
 "class_ogre_1_1_scene_manager.html#ab394162f7351f8701df5a8fee182f7e6":[5,0,9,39,206],
-"class_ogre_1_1_scene_manager.html#ab5ca78b75ee852011cb0c079ac11f67b":[5,0,9,39,271],
+"class_ogre_1_1_scene_manager.html#ab5ca78b75ee852011cb0c079ac11f67b":[5,0,9,39,272],
 "class_ogre_1_1_scene_manager.html#ab7d0636b79f0ae7cc2cae4b92c664cc6":[5,0,9,39,33],
-"class_ogre_1_1_scene_manager.html#ab7f2ff2c074c944a8fca85bc9ef0e8b8":[5,0,9,39,251],
+"class_ogre_1_1_scene_manager.html#ab7f2ff2c074c944a8fca85bc9ef0e8b8":[5,0,9,39,252],
 "class_ogre_1_1_scene_manager.html#ab8ebc8d2fdc6798152ac6a31282de210":[5,0,9,39,160],
-"class_ogre_1_1_scene_manager.html#aba1522f277022ea928223ef9bb8f2806":[5,0,9,39,315],
+"class_ogre_1_1_scene_manager.html#aba1522f277022ea928223ef9bb8f2806":[5,0,9,39,316],
 "class_ogre_1_1_scene_manager.html#aba681db2b43ff006c48da59583b176df":[5,0,9,39,192],
 "class_ogre_1_1_scene_manager.html#abb1b2745f8b8537434dbb1e9a8b4c020":[5,0,9,39,51],
 "class_ogre_1_1_scene_manager.html#abcee0ad945d2d8cfd43097ed378db8d8":[5,0,9,39,144],
@@ -162,20 +178,20 @@ var NAVTREEINDEX38 =
 "class_ogre_1_1_scene_manager.html#ac52887c4c70b39dcaaab5f0785d4b43b":[5,0,9,39,79],
 "class_ogre_1_1_scene_manager.html#ac69e61ce120fc3912e0abe824555928e":[5,0,9,39,157],
 "class_ogre_1_1_scene_manager.html#ac6e42c947472bf09620ef974c3ac26a5":[5,0,9,39,50],
-"class_ogre_1_1_scene_manager.html#ac83d27698223cffeeafd19a9146f51f6":[5,0,9,39,262],
+"class_ogre_1_1_scene_manager.html#ac83d27698223cffeeafd19a9146f51f6":[5,0,9,39,263],
 "class_ogre_1_1_scene_manager.html#ac85bcf0a78e313f723c6894efe020fe5":[5,0,9,39,153],
-"class_ogre_1_1_scene_manager.html#acaf0c820efd7c9870d0630faea7013fa":[5,0,9,39,259],
+"class_ogre_1_1_scene_manager.html#acaf0c820efd7c9870d0630faea7013fa":[5,0,9,39,260],
 "class_ogre_1_1_scene_manager.html#acbc110b48a9c3a45f55a9c6d700fe847":[5,0,9,39,191],
 "class_ogre_1_1_scene_manager.html#acbf7af4f58966c776091f73c383ec2ae":[5,0,9,39,31],
 "class_ogre_1_1_scene_manager.html#acc3d04347b15d26861cb566f71a46685":[5,0,9,39,181],
 "class_ogre_1_1_scene_manager.html#acc59696084663753264961be535d20ba":[5,0,9,39,182],
 "class_ogre_1_1_scene_manager.html#accb0fdfbd1f61aa4d3d6e1f4625e1f9c":[5,0,9,39,108],
-"class_ogre_1_1_scene_manager.html#acd2de135b378c048c4c4a2dff4c73ac8":[5,0,9,39,247],
+"class_ogre_1_1_scene_manager.html#acd2de135b378c048c4c4a2dff4c73ac8":[5,0,9,39,248],
 "class_ogre_1_1_scene_manager.html#acd6f404670e62d2489052b574453f910":[5,0,9,39,94],
 "class_ogre_1_1_scene_manager.html#ace3cf4289a6b9ce4d5547d25153a84e2":[5,0,9,39,42],
 "class_ogre_1_1_scene_manager.html#ad06375ecf563881d80eda76e06ff47c5":[5,0,9,39,178],
-"class_ogre_1_1_scene_manager.html#ad0a84e6426cad7dfd721fb5fccd9976c":[5,0,9,39,308],
-"class_ogre_1_1_scene_manager.html#ad1108eb8e2a42a2c91b4f7473f202b50":[5,0,9,39,268],
+"class_ogre_1_1_scene_manager.html#ad0a84e6426cad7dfd721fb5fccd9976c":[5,0,9,39,309],
+"class_ogre_1_1_scene_manager.html#ad1108eb8e2a42a2c91b4f7473f202b50":[5,0,9,39,269],
 "class_ogre_1_1_scene_manager.html#ad4f344244581a9f727c80a8aa2409283":[5,0,9,39,186],
 "class_ogre_1_1_scene_manager.html#ad716d3752418408f073d9be9bbfe62d0":[5,0,9,39,200],
 "class_ogre_1_1_scene_manager.html#ad72c0a636bfdb7a891de44073ad26835":[5,0,9,39,125],
@@ -183,18 +199,19 @@ var NAVTREEINDEX38 =
 "class_ogre_1_1_scene_manager.html#ad8ff4a3af2f2e35476c1b3250788447b":[5,0,9,39,82],
 "class_ogre_1_1_scene_manager.html#ad9facb91c8cacec792f0952bf1102f9e":[5,0,9,39,56],
 "class_ogre_1_1_scene_manager.html#ada8aa825f1438e92547aa6b37fa566e8":[5,0,9,39,180],
-"class_ogre_1_1_scene_manager.html#adb484fdb3b987874a0396c78e3a0a801":[5,0,9,39,258],
+"class_ogre_1_1_scene_manager.html#adb484fdb3b987874a0396c78e3a0a801":[5,0,9,39,259],
 "class_ogre_1_1_scene_manager.html#adb544a5d5477ef91ef683e4ad5e7a39f":[5,0,9,39,69],
-"class_ogre_1_1_scene_manager.html#adcbf0f49de53a7b67574481703d4fc03":[5,0,9,39,224],
+"class_ogre_1_1_scene_manager.html#adcb97aad29a39d47c7646cdc55650d8f":[5,0,9,39,222],
+"class_ogre_1_1_scene_manager.html#adcbf0f49de53a7b67574481703d4fc03":[5,0,9,39,225],
 "class_ogre_1_1_scene_manager.html#add6959f7447251600bd189008636e887":[5,0,9,39,216],
 "class_ogre_1_1_scene_manager.html#add6fe27d7a9500aafbe9325c21985801":[5,0,9,39,112],
 "class_ogre_1_1_scene_manager.html#ae0f5af4dee25887e0726cb28fd49f722":[5,0,9,39,44],
 "class_ogre_1_1_scene_manager.html#ae291393bc0c5bd48a8c6e79742180c93":[5,0,9,39,116],
 "class_ogre_1_1_scene_manager.html#ae31e995656c34fdaa1c238efd65960b8":[5,0,9,39,194],
-"class_ogre_1_1_scene_manager.html#ae4b6a7748dc4273fd6c160fb162c544f":[5,0,9,39,307],
+"class_ogre_1_1_scene_manager.html#ae4b6a7748dc4273fd6c160fb162c544f":[5,0,9,39,308],
 "class_ogre_1_1_scene_manager.html#ae4e9873e472d78e7595adc3cbbad643a":[5,0,9,39,78],
 "class_ogre_1_1_scene_manager.html#ae68e31e10d39aab32b8ab96455d8adfa":[5,0,9,39,139],
-"class_ogre_1_1_scene_manager.html#ae7115dce2e4a2c2dc49b0996b9279a21":[5,0,9,39,293],
+"class_ogre_1_1_scene_manager.html#ae7115dce2e4a2c2dc49b0996b9279a21":[5,0,9,39,294],
 "class_ogre_1_1_scene_manager.html#ae7fcb66c02d4f364f9e4b0fd9a2673dd":[5,0,9,39,100],
 "class_ogre_1_1_scene_manager.html#ae87a0ee032dd09c82fa13e503711cc2b":[5,0,9,39,123],
 "class_ogre_1_1_scene_manager.html#ae8c44578c47edd67c1c203420fa3d912":[5,0,9,39,170],
@@ -204,8 +221,8 @@ var NAVTREEINDEX38 =
 "class_ogre_1_1_scene_manager.html#aeaff7cf546903bc22c4113c1ae4a7ee4":[5,0,9,39,148],
 "class_ogre_1_1_scene_manager.html#aebb644c23f059b8bfa3702356d19c6be":[5,0,9,39,129],
 "class_ogre_1_1_scene_manager.html#aec115af3cb3741397c4bdbf468cb010b":[5,0,9,39,93],
-"class_ogre_1_1_scene_manager.html#aeca662aaa6dc25f7115ef1c675e34485":[5,0,9,39,227],
-"class_ogre_1_1_scene_manager.html#aeefb47c4d2f8b961381e9b25ab31c22d":[5,0,9,39,316],
+"class_ogre_1_1_scene_manager.html#aeca662aaa6dc25f7115ef1c675e34485":[5,0,9,39,228],
+"class_ogre_1_1_scene_manager.html#aeefb47c4d2f8b961381e9b25ab31c22d":[5,0,9,39,317],
 "class_ogre_1_1_scene_manager.html#aef6a32233813f424dcc1803167fa8d8c":[5,0,9,39,89],
 "class_ogre_1_1_scene_manager.html#aef6d26cb64e7a1984ebff9b56c45c6e5":[5,0,9,39,43],
 "class_ogre_1_1_scene_manager.html#af0c316e631cbbbb85137a328aee28b7c":[5,0,9,39,28],
@@ -214,40 +231,23 @@ var NAVTREEINDEX38 =
 "class_ogre_1_1_scene_manager.html#af1ff02f94ffe6e128f9e9b179737c652":[5,0,9,39,188],
 "class_ogre_1_1_scene_manager.html#af215cf844dc1f3a2cb67b2149938847d":[5,0,9,39,46],
 "class_ogre_1_1_scene_manager.html#af24677a56a91713c40c3bdb9025da38d":[5,0,9,39,30],
-"class_ogre_1_1_scene_manager.html#af32fab74832905ca7c206f81c88f24fa":[5,0,9,39,229],
+"class_ogre_1_1_scene_manager.html#af32fab74832905ca7c206f81c88f24fa":[5,0,9,39,230],
 "class_ogre_1_1_scene_manager.html#af43ffe9afd9bba932fd51cb02496405f":[5,0,9,39,76],
 "class_ogre_1_1_scene_manager.html#af54ce36272c2b70a1ceeb77ace86eb44":[5,0,9,39,151],
-"class_ogre_1_1_scene_manager.html#af55b7d8cf3daf68db0266139faf73492":[5,0,9,39,299],
-"class_ogre_1_1_scene_manager.html#af5bab37a967b021bb03c3c5d840b56ea":[5,0,9,39,261],
+"class_ogre_1_1_scene_manager.html#af55b7d8cf3daf68db0266139faf73492":[5,0,9,39,300],
+"class_ogre_1_1_scene_manager.html#af5bab37a967b021bb03c3c5d840b56ea":[5,0,9,39,262],
 "class_ogre_1_1_scene_manager.html#af5efe579331ee28f3cbe3919db52751f":[5,0,9,39,212],
-"class_ogre_1_1_scene_manager.html#af6005796f7680faa75d9452bcc93bf8b":[5,0,9,39,302],
-"class_ogre_1_1_scene_manager.html#af6c350b864e2bca3132abfd05b9a4b5e":[5,0,9,39,233],
+"class_ogre_1_1_scene_manager.html#af6005796f7680faa75d9452bcc93bf8b":[5,0,9,39,303],
+"class_ogre_1_1_scene_manager.html#af6c350b864e2bca3132abfd05b9a4b5e":[5,0,9,39,234],
 "class_ogre_1_1_scene_manager.html#afaba8c61edcedd1214b8b25e0ad178e4":[5,0,9,39,164],
 "class_ogre_1_1_scene_manager.html#afb5bb25f8bec41a2a0cf9a6479bb309e":[5,0,9,39,41],
-"class_ogre_1_1_scene_manager.html#afc225e6c4de27fec3855c725cef29b06":[5,0,9,39,300],
-"class_ogre_1_1_scene_manager.html#afcc3ad744c0bd91c63db369a70141482":[5,0,9,39,313],
+"class_ogre_1_1_scene_manager.html#afc225e6c4de27fec3855c725cef29b06":[5,0,9,39,301],
+"class_ogre_1_1_scene_manager.html#afcc3ad744c0bd91c63db369a70141482":[5,0,9,39,314],
 "class_ogre_1_1_scene_manager.html#afce67977a494e9d9314530c0edeb18eb":[5,0,9,39,104],
 "class_ogre_1_1_scene_manager.html#afe9440db228af3fdc39d4fd4d96a0935":[5,0,9,39,91],
-"class_ogre_1_1_scene_manager.html#aff2097540f9f80235394436b3178a159":[5,0,9,39,255],
+"class_ogre_1_1_scene_manager.html#aff2097540f9f80235394436b3178a159":[5,0,9,39,256],
 "class_ogre_1_1_scene_manager.html#affcefaa227a8b0de8dc800e53a4ac10f":[5,0,9,39,38],
 "class_ogre_1_1_scene_manager_1_1_listener.html":[5,0,9,39,0],
 "class_ogre_1_1_scene_manager_1_1_listener.html#a05a9a139f53f89d5595c4f3101ea53d3":[5,0,9,39,0,0],
-"class_ogre_1_1_scene_manager_1_1_listener.html#a084b73ccf5c6677ab2c22c3a912fbae1":[5,0,9,39,0,1],
-"class_ogre_1_1_scene_manager_1_1_listener.html#a2c0007528c775ca51c95fd5e7f7aa4db":[5,0,9,39,0,4],
-"class_ogre_1_1_scene_manager_1_1_listener.html#a9d5463252458a8852b0011935e6f5bb5":[5,0,9,39,0,6],
-"class_ogre_1_1_scene_manager_1_1_listener.html#aaafbc877eaf190b86163c1e171a4400e":[5,0,9,39,0,2],
-"class_ogre_1_1_scene_manager_1_1_listener.html#ab57b560ea987d8dae9901908d0ab6f28":[5,0,9,39,0,5],
-"class_ogre_1_1_scene_manager_1_1_listener.html#ad8f0c1e1efaccade0663e416d76b960c":[5,0,9,39,0,3],
-"class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html":[5,0,9,39,2],
-"class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#a1debd6d9332b92a9a2a40077ba908427":[5,0,9,39,2,0],
-"class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#a1f81a13b0b7ff39afa5e96e35728a40e":[5,0,9,39,2,10],
-"class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#a5a00a39fe1147c5806c457a4a9feed88":[5,0,9,39,2,6],
-"class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#a5aded8430792e58ecc85c0d5bf0a360a":[5,0,9,39,2,2],
-"class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#a985f47ccacf0d434b3b80fd7fc06adce":[5,0,9,39,2,3],
-"class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#a9b568558ac92b819f6c141cfae20613f":[5,0,9,39,2,7],
-"class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#aa05f120964ef4bf3127dffa67c03480a":[5,0,9,39,2,9],
-"class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#aaeb00285e4af4ab37e85b95801cb9af5":[5,0,9,39,2,4],
-"class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#ac8c6da90e0c6ca347c97acdf9b3e8dff":[5,0,9,39,2,1],
-"class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#acf473d568a738bb42e81ef872fe600a2":[5,0,9,39,2,8],
-"class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#af669ba0b9cb88fd2c6ceb4fa2aa816f5":[5,0,9,39,2,5]
+"class_ogre_1_1_scene_manager_1_1_listener.html#a084b73ccf5c6677ab2c22c3a912fbae1":[5,0,9,39,0,1]
 };
