@@ -1,5 +1,6 @@
 var NAVTREEINDEX4 =
 {
+"building-ogre.html#autotoc_md274":[2,0,7,3],
 "building-ogre.html#installing-sdk":[2,0,5],
 "building-ogre.html#running-cmake":[2,0,3],
 "citelist.html":[4],
@@ -248,6 +249,5 @@ var NAVTREEINDEX4 =
 "class_ogre_1_1_animation_track.html#ac330c1a17fe9c935dc96ea3e359c98ac":[5,0,0,8,5],
 "class_ogre_1_1_animation_track.html#ad96281be1b189c69a1dbd2283d583503":[5,0,0,8,14],
 "class_ogre_1_1_animation_track.html#ae65e63b3f5b7dc7425d6071ce987ceaf":[5,0,0,8,6],
-"class_ogre_1_1_animation_track.html#aed855e8117300af01d646ff49b020916":[5,0,0,8,17],
-"class_ogre_1_1_animation_track.html#afcc48b8a78792024e88eb7ff3e1ffc3c":[5,0,0,8,7]
+"class_ogre_1_1_animation_track.html#aed855e8117300af01d646ff49b020916":[5,0,0,8,17]
 };
