@@ -1,5 +1,21 @@
 var NAVTREEINDEX48 =
 {
+"class_ogre_1_1_volume_1_1_c_s_g_operation_source.html#aed8af4851207f80b09f2c17bcb9202e9":[5,1,9,9,2],
+"class_ogre_1_1_volume_1_1_c_s_g_plane_source.html":[5,1,9,10],
+"class_ogre_1_1_volume_1_1_c_s_g_plane_source.html#a72e6ddc3d83574a122cfaeb6fec15a8f":[5,1,9,10,0],
+"class_ogre_1_1_volume_1_1_c_s_g_plane_source.html#a91e7400b407ef91a62a09b9801ccd1ad":[5,1,9,10,1],
+"class_ogre_1_1_volume_1_1_c_s_g_plane_source.html#ac3b244d7cb136a303bbdebb14429646d":[5,1,9,10,2],
+"class_ogre_1_1_volume_1_1_c_s_g_scale_source.html":[5,1,9,11],
+"class_ogre_1_1_volume_1_1_c_s_g_scale_source.html#a4ab1cb67080d74aeddbce5de4528ea6a":[5,1,9,11,1],
+"class_ogre_1_1_volume_1_1_c_s_g_scale_source.html#a94f26a84a61b224e3836a8916df7153f":[5,1,9,11,0],
+"class_ogre_1_1_volume_1_1_c_s_g_scale_source.html#acf2c46521033b41d213c36616f5d0f99":[5,1,9,11,2],
+"class_ogre_1_1_volume_1_1_c_s_g_sphere_source.html":[5,1,9,12],
+"class_ogre_1_1_volume_1_1_c_s_g_sphere_source.html#a175cd00ed506493006ba0a51be7cd334":[5,1,9,12,0],
+"class_ogre_1_1_volume_1_1_c_s_g_sphere_source.html#a2b471d87caa4a711bff60d9b435f8732":[5,1,9,12,2],
+"class_ogre_1_1_volume_1_1_c_s_g_sphere_source.html#aa7656897c9690414dbcbb9d01ea6c124":[5,1,9,12,1],
+"class_ogre_1_1_volume_1_1_c_s_g_unary_source.html":[5,1,9,13],
+"class_ogre_1_1_volume_1_1_c_s_g_unary_source.html#a0324f86ebd17d5f269f22bcbc3f616a1":[5,1,9,13,0],
+"class_ogre_1_1_volume_1_1_c_s_g_unary_source.html#a6d9e9b235c107413c2025d2a72dd0494":[5,1,9,13,1],
 "class_ogre_1_1_volume_1_1_c_s_g_union_source.html":[5,1,9,14],
 "class_ogre_1_1_volume_1_1_c_s_g_union_source.html#a24304808fb8be804cbbcb0e8f3ef81f8":[5,1,9,14,1],
 "class_ogre_1_1_volume_1_1_c_s_g_union_source.html#a3e2ac54f1442c334e4ef6711d668e9f8":[5,1,9,14,3],
@@ -149,58 +165,57 @@ var NAVTREEINDEX48 =
 "class_ogre_1_1_volume_1_1_texture_source.html#a51f4b9935b05a336bbf1de1649e3bce9":[5,1,9,27,0],
 "class_ogre_1_1_vulkan_render_system.html":[5,3,7,0],
 "class_ogre_1_1_vulkan_render_system.html#a0f640811fe28305eb25b6c0227700c01":[5,3,7,0,19],
-"class_ogre_1_1_vulkan_render_system.html#a173fc746de1f1b5314492a5e39e9d7e2":[5,3,7,0,39],
-"class_ogre_1_1_vulkan_render_system.html#a2a12953476946e6b8e5f1478f1e5d009":[5,3,7,0,35],
-"class_ogre_1_1_vulkan_render_system.html#a2b20fa848e3174bde8773f03adb3e3b8":[5,3,7,0,51],
+"class_ogre_1_1_vulkan_render_system.html#a173fc746de1f1b5314492a5e39e9d7e2":[5,3,7,0,38],
+"class_ogre_1_1_vulkan_render_system.html#a2a12953476946e6b8e5f1478f1e5d009":[5,3,7,0,34],
+"class_ogre_1_1_vulkan_render_system.html#a2b20fa848e3174bde8773f03adb3e3b8":[5,3,7,0,50],
 "class_ogre_1_1_vulkan_render_system.html#a2e54186f2f5b1bbc38f5cb37b12ca8f1":[5,3,7,0,29],
-"class_ogre_1_1_vulkan_render_system.html#a2fdf7eed46d3fdb4c29cad9b4874d927":[5,3,7,0,50],
+"class_ogre_1_1_vulkan_render_system.html#a2fdf7eed46d3fdb4c29cad9b4874d927":[5,3,7,0,49],
 "class_ogre_1_1_vulkan_render_system.html#a3256329a9db37b1a3f1d9093d287372c":[5,3,7,0,0],
-"class_ogre_1_1_vulkan_render_system.html#a332fee961038567d8fb920b921da59f0":[5,3,7,0,41],
+"class_ogre_1_1_vulkan_render_system.html#a332fee961038567d8fb920b921da59f0":[5,3,7,0,40],
 "class_ogre_1_1_vulkan_render_system.html#a3821c672f460b2edf5cfbf195c99bd87":[5,3,7,0,10],
 "class_ogre_1_1_vulkan_render_system.html#a3cba4e8bea2139463514aa7f0b5a0cf2":[5,3,7,0,15],
 "class_ogre_1_1_vulkan_render_system.html#a3d7d5565a465cb6ea13717a92b2576f2":[5,3,7,0,11],
 "class_ogre_1_1_vulkan_render_system.html#a3e48a4221b9e63d3e7ffb9c46d1a5eb2":[5,3,7,0,2],
-"class_ogre_1_1_vulkan_render_system.html#a3f51feb767ea33be6731a75d27d9c5d5":[5,3,7,0,46],
-"class_ogre_1_1_vulkan_render_system.html#a401c8aca49c77a4df2d2e6a795b1f876":[5,3,7,0,34],
+"class_ogre_1_1_vulkan_render_system.html#a3f51feb767ea33be6731a75d27d9c5d5":[5,3,7,0,45],
+"class_ogre_1_1_vulkan_render_system.html#a401c8aca49c77a4df2d2e6a795b1f876":[5,3,7,0,33],
 "class_ogre_1_1_vulkan_render_system.html#a43335f6a8b543999a085803a9f78bafe":[5,3,7,0,14],
 "class_ogre_1_1_vulkan_render_system.html#a4356b2ab5a8fb27f66f13df2b9e64f4f":[5,3,7,0,17],
-"class_ogre_1_1_vulkan_render_system.html#a44c81d53a28b5aeb83f2ed85231a29ee":[5,3,7,0,43],
+"class_ogre_1_1_vulkan_render_system.html#a44c81d53a28b5aeb83f2ed85231a29ee":[5,3,7,0,42],
 "class_ogre_1_1_vulkan_render_system.html#a496a02ae196b58a13bd6f02090a45641":[5,3,7,0,13],
 "class_ogre_1_1_vulkan_render_system.html#a5705e3689a6e4f9695daa5bf4549f71c":[5,3,7,0,18],
-"class_ogre_1_1_vulkan_render_system.html#a62af66b18c254e7129ff316065688275":[5,3,7,0,55],
+"class_ogre_1_1_vulkan_render_system.html#a62af66b18c254e7129ff316065688275":[5,3,7,0,54],
 "class_ogre_1_1_vulkan_render_system.html#a662adfeeae0156349100e2041fb0e69f":[5,3,7,0,6],
 "class_ogre_1_1_vulkan_render_system.html#a691b5029fbd88f511e9d20595cf5f9ed":[5,3,7,0,26],
-"class_ogre_1_1_vulkan_render_system.html#a6a71a101938a424c03582c08fe90d2e1":[5,3,7,0,45],
-"class_ogre_1_1_vulkan_render_system.html#a6d46fc83594f7af92b41780a318eb146":[5,3,7,0,53],
+"class_ogre_1_1_vulkan_render_system.html#a6a71a101938a424c03582c08fe90d2e1":[5,3,7,0,44],
+"class_ogre_1_1_vulkan_render_system.html#a6d46fc83594f7af92b41780a318eb146":[5,3,7,0,52],
 "class_ogre_1_1_vulkan_render_system.html#a717e68a43a58586c8657eeab9a7e70f0":[5,3,7,0,12],
 "class_ogre_1_1_vulkan_render_system.html#a788f92ac70cf09f5b4d052bcaa9ba7ba":[5,3,7,0,7],
-"class_ogre_1_1_vulkan_render_system.html#a7b4fa74c06c32ee4c1f79ff774acf973":[5,3,7,0,47],
+"class_ogre_1_1_vulkan_render_system.html#a7b4fa74c06c32ee4c1f79ff774acf973":[5,3,7,0,46],
 "class_ogre_1_1_vulkan_render_system.html#a7c7413d33c75a04a5539f5675f559c5c":[5,3,7,0,1],
 "class_ogre_1_1_vulkan_render_system.html#a83baebb09f27798e5d81a87448f13d06":[5,3,7,0,25],
-"class_ogre_1_1_vulkan_render_system.html#a91a68815ab1874cf585f400454fae611":[5,3,7,0,40],
+"class_ogre_1_1_vulkan_render_system.html#a91a68815ab1874cf585f400454fae611":[5,3,7,0,39],
 "class_ogre_1_1_vulkan_render_system.html#a91c92d4e83797e670adf672c3f0de1ab":[5,3,7,0,4],
-"class_ogre_1_1_vulkan_render_system.html#a92c2f421d60d703f5a2265ea9cbc0bd3":[5,3,7,0,52],
+"class_ogre_1_1_vulkan_render_system.html#a92c2f421d60d703f5a2265ea9cbc0bd3":[5,3,7,0,51],
 "class_ogre_1_1_vulkan_render_system.html#a984c96c8d6d20a1b6888e11cd3295ce3":[5,3,7,0,9],
-"class_ogre_1_1_vulkan_render_system.html#aa15ef018cd16253927e1861942dfc938":[5,3,7,0,44],
-"class_ogre_1_1_vulkan_render_system.html#aa31e6cbd12da593d6759f15ced351458":[5,3,7,0,31],
-"class_ogre_1_1_vulkan_render_system.html#aa5870e4d7408c1eccde389497bec1a5b":[5,3,7,0,49],
-"class_ogre_1_1_vulkan_render_system.html#aa6e8b65ee1b8839a9d6ab6b2f28dfb33":[5,3,7,0,32],
-"class_ogre_1_1_vulkan_render_system.html#aa7810530cfd3855165e14d7a032b5308":[5,3,7,0,36],
+"class_ogre_1_1_vulkan_render_system.html#aa15ef018cd16253927e1861942dfc938":[5,3,7,0,43],
+"class_ogre_1_1_vulkan_render_system.html#aa5870e4d7408c1eccde389497bec1a5b":[5,3,7,0,48],
+"class_ogre_1_1_vulkan_render_system.html#aa6e8b65ee1b8839a9d6ab6b2f28dfb33":[5,3,7,0,31],
+"class_ogre_1_1_vulkan_render_system.html#aa7810530cfd3855165e14d7a032b5308":[5,3,7,0,35],
 "class_ogre_1_1_vulkan_render_system.html#aab91ba8d7167630b0528b8f3d1c0cbf1":[5,3,7,0,28],
-"class_ogre_1_1_vulkan_render_system.html#ab10cc3cb075545a2ef04fe6623930554":[5,3,7,0,42],
-"class_ogre_1_1_vulkan_render_system.html#abcb05700f055cd677568de4b98788312":[5,3,7,0,33],
+"class_ogre_1_1_vulkan_render_system.html#ab10cc3cb075545a2ef04fe6623930554":[5,3,7,0,41],
+"class_ogre_1_1_vulkan_render_system.html#abcb05700f055cd677568de4b98788312":[5,3,7,0,32],
 "class_ogre_1_1_vulkan_render_system.html#abda2342248fd9c5e4bc5c200a142297e":[5,3,7,0,3],
 "class_ogre_1_1_vulkan_render_system.html#ac88fd177ee265df40400f20e9eff9954":[5,3,7,0,30],
 "class_ogre_1_1_vulkan_render_system.html#ace615111b92d64d66f024d22d69c8b54":[5,3,7,0,22],
-"class_ogre_1_1_vulkan_render_system.html#acf5794ce21e0119d76a51d9571433d33":[5,3,7,0,38],
-"class_ogre_1_1_vulkan_render_system.html#acfdd8b5133eec38488707a45140eeaa3":[5,3,7,0,48],
+"class_ogre_1_1_vulkan_render_system.html#acf5794ce21e0119d76a51d9571433d33":[5,3,7,0,37],
+"class_ogre_1_1_vulkan_render_system.html#acfdd8b5133eec38488707a45140eeaa3":[5,3,7,0,47],
 "class_ogre_1_1_vulkan_render_system.html#adb02caab3bd1c1533cc7e90c7ad36fa1":[5,3,7,0,20],
 "class_ogre_1_1_vulkan_render_system.html#adb4b68f81677422377a02fe57c06466d":[5,3,7,0,5],
 "class_ogre_1_1_vulkan_render_system.html#adb98f87978b8694d643d88bbe8b13911":[5,3,7,0,21],
-"class_ogre_1_1_vulkan_render_system.html#ae06a81d2ef6b5afca19f234d3a38b6f2":[5,3,7,0,37],
+"class_ogre_1_1_vulkan_render_system.html#ae06a81d2ef6b5afca19f234d3a38b6f2":[5,3,7,0,36],
 "class_ogre_1_1_vulkan_render_system.html#aeb4249b35982b6cadff7d541d03a89e0":[5,3,7,0,8],
 "class_ogre_1_1_vulkan_render_system.html#af222d1c3db1422c6e4cf769c4b13898b":[5,3,7,0,27],
-"class_ogre_1_1_vulkan_render_system.html#af4f86f020385d9edecf32a2005d6ac4c":[5,3,7,0,54],
+"class_ogre_1_1_vulkan_render_system.html#af4f86f020385d9edecf32a2005d6ac4c":[5,3,7,0,53],
 "class_ogre_1_1_vulkan_render_system.html#af6883fca272c65b8e877dfaccb2ab4e1":[5,3,7,0,24],
 "class_ogre_1_1_vulkan_render_system.html#af8509e9a30df823db2ac70607a571563":[5,3,7,0,16],
 "class_ogre_1_1_vulkan_render_system.html#afb549e48d2fa21f9d3f95a57762be738":[5,3,7,0,23],
@@ -234,20 +249,5 @@ var NAVTREEINDEX48 =
 "class_ogre_1_1_work_queue.html#aa4791d719ff478021ccc66b09fec01f2":[5,0,2,51,13],
 "class_ogre_1_1_work_queue.html#aadcc7937baf48a49eec4c0d321852211":[5,0,2,51,8],
 "class_ogre_1_1_work_queue.html#abc8685f2e0f4921468f8cf7cb5f2b2b3":[5,0,2,51,12],
-"class_ogre_1_1_work_queue.html#ad6d7aeeb4b1e4e8eed931cb17d63add3":[5,0,2,51,7],
-"class_ogre_1_1_work_queue_1_1_request.html":[5,0,2,51,0],
-"class_ogre_1_1_work_queue_1_1_request.html#a060279eea8f56ee894b5fcd821938b2d":[5,0,2,51,0,2],
-"class_ogre_1_1_work_queue_1_1_request.html#a43e13c709cfee50891c7b03ff99073fc":[5,0,2,51,0,5],
-"class_ogre_1_1_work_queue_1_1_request.html#a702f89b4a3f1e8aa383be5894b2ed29c":[5,0,2,51,0,3],
-"class_ogre_1_1_work_queue_1_1_request.html#a9ada381b6f00e875b2e6b00e6ea9e205":[5,0,2,51,0,6],
-"class_ogre_1_1_work_queue_1_1_request.html#ab2db68c857606e5c15ef163d12f6e033":[5,0,2,51,0,4],
-"class_ogre_1_1_work_queue_1_1_request.html#abc6f573b83b9828f994bca37720bfa1d":[5,0,2,51,0,1],
-"class_ogre_1_1_work_queue_1_1_request.html#af4747a039d3166c38a0f0646f87d10f4":[5,0,2,51,0,0],
-"class_ogre_1_1_work_queue_1_1_request.html#afc5a5e65333384e477426c2f77353b28":[5,0,2,51,0,7],
-"class_ogre_1_1_zip_archive_factory.html":[5,0,8,32],
-"class_ogre_1_1_zip_archive_factory.html#a10ac98b6faf4f73496a0afc31f9bb6be":[5,0,8,32,1],
-"class_ogre_1_1_zip_archive_factory.html#a4e04c7925c6191405257dc4751957eb6":[5,0,8,32,2],
-"class_ogre_1_1_zip_archive_factory.html#ab1151aa6471ec8ff2be0f6555be51c8a":[5,0,8,32,0],
-"class_ogre_1_1_zone_data.html":[5,2,9,10],
-"class_ogre_1_1_zone_data.html#a0e85d178c29c65bc6cd9117f48770f4d":[5,2,9,10,3]
+"class_ogre_1_1_work_queue.html#ad6d7aeeb4b1e4e8eed931cb17d63add3":[5,0,2,51,7]
 };
