@@ -1,5 +1,30 @@
 var NAVTREEINDEX63 =
 {
+"struct_ogre_1_1_vertex_data_1_1_hardware_animation_data.html":[5,0,7,40,0],
+"struct_ogre_1_1_vertex_data_1_1_hardware_animation_data.html#a0662d8e6ede8a7cdbb387db40e77c989":[5,0,7,40,0,0],
+"struct_ogre_1_1_vertex_data_1_1_hardware_animation_data.html#afb5a1e2fb60698c421bb419be6f41026":[5,0,7,40,0,1],
+"struct_ogre_1_1_vertex_pose_key_frame_1_1_pose_ref.html":[5,0,0,36,0],
+"struct_ogre_1_1_vertex_pose_key_frame_1_1_pose_ref.html#a049f2fa04d1bd43409beb863f72738cb":[5,0,0,36,0,0],
+"struct_ogre_1_1_vertex_pose_key_frame_1_1_pose_ref.html#a172a06f5c2697f3e20bc2cf8556708ab":[5,0,0,36,0,1],
+"struct_ogre_1_1_vertex_pose_key_frame_1_1_pose_ref.html#a1d5ba485439bea7af10cc0d1f6972d60":[5,0,0,36,0,2],
+"struct_ogre_1_1_view_point.html":[5,0,9,57],
+"struct_ogre_1_1_view_point.html#a3c5ae8fe5c3adce148bfebd3ed9b8e56":[5,0,9,57,0],
+"struct_ogre_1_1_view_point.html#a6a25f94ff18e79c7bf0e275f60494d89":[5,0,9,57,1],
+"struct_ogre_1_1_visible_objects_bounds_info.html":[5,0,9,58],
+"struct_ogre_1_1_visible_objects_bounds_info.html#a2619f0cbd6507670ba39df1ae16c2187":[5,0,9,58,2],
+"struct_ogre_1_1_visible_objects_bounds_info.html#a27ab7b6458b47fade5858c4ec457dd2f":[5,0,9,58,7],
+"struct_ogre_1_1_visible_objects_bounds_info.html#a2bbff049935d8d0eb89d49cc74a89431":[5,0,9,58,0],
+"struct_ogre_1_1_visible_objects_bounds_info.html#a2d0696c263b1c322f93c21291329c00e":[5,0,9,58,3],
+"struct_ogre_1_1_visible_objects_bounds_info.html#a3020f462ae4980e068c60fb94ced0c9a":[5,0,9,58,5],
+"struct_ogre_1_1_visible_objects_bounds_info.html#a3054df454ccf16dc5ff558a23bafff1d":[5,0,9,58,9],
+"struct_ogre_1_1_visible_objects_bounds_info.html#a7af1e407d66960fa69fd37e897415f31":[5,0,9,58,4],
+"struct_ogre_1_1_visible_objects_bounds_info.html#a821c0a7e158c459f30fd83e214bb47d3":[5,0,9,58,6],
+"struct_ogre_1_1_visible_objects_bounds_info.html#ae17227fc412fe731987dee3e12591002":[5,0,9,58,8],
+"struct_ogre_1_1_visible_objects_bounds_info.html#ae30061f7fee451b125003e00b2254805":[5,0,9,58,1],
+"struct_ogre_1_1_volume_1_1_chunk_parameters.html":[5,1,9,2],
+"struct_ogre_1_1_volume_1_1_chunk_parameters.html#a066adb42505bd30a78f1553a1913d273":[5,1,9,2,5],
+"struct_ogre_1_1_volume_1_1_chunk_parameters.html#a111c9e9333e7ae3497fc818190a03fd8":[5,1,9,2,2],
+"struct_ogre_1_1_volume_1_1_chunk_parameters.html#a3e154a179b8c824f79b1b426608743ad":[5,1,9,2,1],
 "struct_ogre_1_1_volume_1_1_chunk_parameters.html#a4444eac27c71e02886615dcf7fbfed27":[5,1,9,2,3],
 "struct_ogre_1_1_volume_1_1_chunk_parameters.html#a61d33b21a20c4fe9645545bdfe3029c3":[5,1,9,2,6],
 "struct_ogre_1_1_volume_1_1_chunk_parameters.html#a6403e2875cc7b81aefd43ba9f22c2b31":[5,1,9,2,8],
@@ -149,105 +174,80 @@ var NAVTREEINDEX63 =
 "struct_ogre_bites_1_1_button_event.html#a3e3d90a330a391784b466ca235abca9a":[5,1,0,0,1,2],
 "struct_ogre_bites_1_1_button_event.html#a40608cbf85650687e8601bcd35c73ba0":[5,1,0,0,1,0],
 "struct_ogre_bites_1_1_button_event.html#a7031f8c4dfa30fafb48605fc2b75a752":[5,1,0,0,1,1],
-"struct_ogre_bites_1_1_im_gui_input_listener.html":[6,0,2,10],
-"struct_ogre_bites_1_1_im_gui_input_listener.html":[7,0,1,10],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#a181f93f3558078c4126323784f0c3038":[6,0,2,10,6],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#a181f93f3558078c4126323784f0c3038":[7,0,1,10,6],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#a1eefc4a8fe9bc22fc014f61299f77a88":[6,0,2,10,1],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#a1eefc4a8fe9bc22fc014f61299f77a88":[7,0,1,10,1],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#a3caf056544efbc37b5f93e75f8b45f94":[6,0,2,10,7],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#a3caf056544efbc37b5f93e75f8b45f94":[7,0,1,10,7],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#a4ea69a12f0fc9b077ce412db0665d785":[6,0,2,10,4],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#a4ea69a12f0fc9b077ce412db0665d785":[7,0,1,10,4],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#a5b9a5d887ccafe2dca501909f0853f32":[6,0,2,10,9],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#a5b9a5d887ccafe2dca501909f0853f32":[7,0,1,10,9],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#a701f4ac244f30c7a1db50e7ba6c70f8a":[6,0,2,10,0],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#a701f4ac244f30c7a1db50e7ba6c70f8a":[7,0,1,10,0],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#aae8fcd284dc8abd7dbe1d88bc151ca1e":[6,0,2,10,8],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#aae8fcd284dc8abd7dbe1d88bc151ca1e":[7,0,1,10,8],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#abcab9da1f01a36e9b47feca674e2c93d":[6,0,2,10,5],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#abcab9da1f01a36e9b47feca674e2c93d":[7,0,1,10,5],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#ac953a548ebb6190669a466da44097b01":[6,0,2,10,3],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#ac953a548ebb6190669a466da44097b01":[7,0,1,10,3],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#ae66e4c077a56dfd1aefc3d04dc8bfde1":[6,0,2,10,2],
-"struct_ogre_bites_1_1_im_gui_input_listener.html#ae66e4c077a56dfd1aefc3d04dc8bfde1":[7,0,1,10,2],
-"struct_ogre_bites_1_1_input_listener.html":[5,1,0,0,3],
-"struct_ogre_bites_1_1_input_listener.html#a187cf425349d33fd12766e6f90ff96d5":[5,1,0,0,3,6],
-"struct_ogre_bites_1_1_input_listener.html#a2b4b1935223889fbfb9977579cadb4e9":[5,1,0,0,3,8],
-"struct_ogre_bites_1_1_input_listener.html#a345f8b5b0fb84f236bf58f8d8fbf5102":[5,1,0,0,3,0],
-"struct_ogre_bites_1_1_input_listener.html#a3f81e48ecc2fd9438a548d73501d1c90":[5,1,0,0,3,5],
-"struct_ogre_bites_1_1_input_listener.html#a4534ef767309188cee16e4017054cccd":[5,1,0,0,3,10],
-"struct_ogre_bites_1_1_input_listener.html#a61ba63d9edb3d64ef8ef93b0fafa79f4":[5,1,0,0,3,14],
-"struct_ogre_bites_1_1_input_listener.html#a6b5bb758dff77d6de9c6fad00ddbe591":[5,1,0,0,3,12],
-"struct_ogre_bites_1_1_input_listener.html#a76ba51407cec5b5688c94aab2126cd3b":[5,1,0,0,3,4],
-"struct_ogre_bites_1_1_input_listener.html#a7b4d9fcb9c5e6e81e92ab02d485ad510":[5,1,0,0,3,3],
-"struct_ogre_bites_1_1_input_listener.html#aa2e3f9569ad2c28ea0ec5d48b5ddb9e0":[5,1,0,0,3,9],
-"struct_ogre_bites_1_1_input_listener.html#aab02e8b14e95a78dfc5ae694104aef56":[5,1,0,0,3,11],
-"struct_ogre_bites_1_1_input_listener.html#abe5f72cb4f631c440bb5a8f699da90d2":[5,1,0,0,3,2],
-"struct_ogre_bites_1_1_input_listener.html#ac3f2ee3ec9de5a294260880a04ec3259":[5,1,0,0,3,1],
-"struct_ogre_bites_1_1_input_listener.html#ac4a3dc2ca71bdd0e138889050d5be727":[5,1,0,0,3,7],
-"struct_ogre_bites_1_1_input_listener.html#aebffd0d3efd1403c3f30ea9bd4290f26":[5,1,0,0,3,13],
-"struct_ogre_bites_1_1_keyboard_event.html":[5,1,0,0,5],
-"struct_ogre_bites_1_1_keyboard_event.html#a2b2b87cad3f82fb272e86c115fc744c8":[5,1,0,0,5,2],
-"struct_ogre_bites_1_1_keyboard_event.html#a43602aaa9c30b36a13c2c4b4eccbecd9":[5,1,0,0,5,0],
-"struct_ogre_bites_1_1_keyboard_event.html#a675789f0663c8e7c8ac38db339a98a60":[5,1,0,0,5,1],
-"struct_ogre_bites_1_1_keysym.html":[5,1,0,0,6],
-"struct_ogre_bites_1_1_keysym.html#a0174848a10c2790beb05a3f21317a5c3":[5,1,0,0,6,0],
-"struct_ogre_bites_1_1_keysym.html#a41e0a1ecbac3b262fe419371ef74da99":[5,1,0,0,6,1],
-"struct_ogre_bites_1_1_mouse_button_event.html":[5,1,0,0,7],
-"struct_ogre_bites_1_1_mouse_button_event.html#a0e23a52e12f37f0021ae358592adc721":[5,1,0,0,7,2],
-"struct_ogre_bites_1_1_mouse_button_event.html#a5a726cd5b2d0ac069c96e8bf85cd93bc":[5,1,0,0,7,1],
-"struct_ogre_bites_1_1_mouse_button_event.html#a83011c2613d0e6c4b4b639a9e727d6b3":[5,1,0,0,7,4],
-"struct_ogre_bites_1_1_mouse_button_event.html#aa676b58a32cec113f18fe1a1ccf5a1c9":[5,1,0,0,7,0],
-"struct_ogre_bites_1_1_mouse_button_event.html#aab3921d012481b923b8e85dc7a9a1059":[5,1,0,0,7,3],
-"struct_ogre_bites_1_1_mouse_motion_event.html":[5,1,0,0,8],
-"struct_ogre_bites_1_1_mouse_motion_event.html#a154f56c1e7973e1093e8e9790b891905":[5,1,0,0,8,2],
-"struct_ogre_bites_1_1_mouse_motion_event.html#a5ec248b9fa2d12b77758b260d6c6d13f":[5,1,0,0,8,0],
-"struct_ogre_bites_1_1_mouse_motion_event.html#a7e5b81289ae8a00f47a2989e809fc944":[5,1,0,0,8,3],
-"struct_ogre_bites_1_1_mouse_motion_event.html#a92edfa8cded01b6b59375a92855a3034":[5,1,0,0,8,1],
-"struct_ogre_bites_1_1_mouse_motion_event.html#a9df7243dbc2adc4deb99da321aae7e96":[5,1,0,0,8,5],
-"struct_ogre_bites_1_1_mouse_motion_event.html#af22000e1b37946e6f4517160ce19562b":[5,1,0,0,8,4],
-"struct_ogre_bites_1_1_mouse_wheel_event.html":[5,1,0,0,9],
-"struct_ogre_bites_1_1_mouse_wheel_event.html#a27ed30513a79d9812254a72e29bf5e11":[5,1,0,0,9,0],
-"struct_ogre_bites_1_1_mouse_wheel_event.html#a94bdc0e9db916b9240048bdb7240488e":[5,1,0,0,9,1],
+"struct_ogre_bites_1_1_hat_event.html":[5,1,0,0,3],
+"struct_ogre_bites_1_1_hat_event.html#a2c9be40eaf8f718442816f80f697c9c5":[5,1,0,0,3,1],
+"struct_ogre_bites_1_1_hat_event.html#a778f8b5d0b7b14b291eeff59965ab188":[5,1,0,0,3,2],
+"struct_ogre_bites_1_1_hat_event.html#a835b5a9db7cb13320986517758280878":[5,1,0,0,3,3],
+"struct_ogre_bites_1_1_hat_event.html#ad1a6a0c81793de6273745939f6ddb1c3":[5,1,0,0,3,0],
+"struct_ogre_bites_1_1_im_gui_input_listener.html":[6,0,2,11],
+"struct_ogre_bites_1_1_im_gui_input_listener.html":[7,0,1,11],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#a181f93f3558078c4126323784f0c3038":[6,0,2,11,6],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#a181f93f3558078c4126323784f0c3038":[7,0,1,11,6],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#a1eefc4a8fe9bc22fc014f61299f77a88":[6,0,2,11,1],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#a1eefc4a8fe9bc22fc014f61299f77a88":[7,0,1,11,1],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#a3caf056544efbc37b5f93e75f8b45f94":[6,0,2,11,7],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#a3caf056544efbc37b5f93e75f8b45f94":[7,0,1,11,7],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#a4ea69a12f0fc9b077ce412db0665d785":[6,0,2,11,4],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#a4ea69a12f0fc9b077ce412db0665d785":[7,0,1,11,4],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#a5b9a5d887ccafe2dca501909f0853f32":[6,0,2,11,9],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#a5b9a5d887ccafe2dca501909f0853f32":[7,0,1,11,9],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#a701f4ac244f30c7a1db50e7ba6c70f8a":[6,0,2,11,0],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#a701f4ac244f30c7a1db50e7ba6c70f8a":[7,0,1,11,0],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#aae8fcd284dc8abd7dbe1d88bc151ca1e":[6,0,2,11,8],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#aae8fcd284dc8abd7dbe1d88bc151ca1e":[7,0,1,11,8],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#abcab9da1f01a36e9b47feca674e2c93d":[6,0,2,11,5],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#abcab9da1f01a36e9b47feca674e2c93d":[7,0,1,11,5],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#ac953a548ebb6190669a466da44097b01":[6,0,2,11,3],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#ac953a548ebb6190669a466da44097b01":[7,0,1,11,3],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#ae66e4c077a56dfd1aefc3d04dc8bfde1":[6,0,2,11,2],
+"struct_ogre_bites_1_1_im_gui_input_listener.html#ae66e4c077a56dfd1aefc3d04dc8bfde1":[7,0,1,11,2],
+"struct_ogre_bites_1_1_input_listener.html":[5,1,0,0,4],
+"struct_ogre_bites_1_1_input_listener.html#a187cf425349d33fd12766e6f90ff96d5":[5,1,0,0,4,6],
+"struct_ogre_bites_1_1_input_listener.html#a2b4b1935223889fbfb9977579cadb4e9":[5,1,0,0,4,8],
+"struct_ogre_bites_1_1_input_listener.html#a345f8b5b0fb84f236bf58f8d8fbf5102":[5,1,0,0,4,0],
+"struct_ogre_bites_1_1_input_listener.html#a3f81e48ecc2fd9438a548d73501d1c90":[5,1,0,0,4,5],
+"struct_ogre_bites_1_1_input_listener.html#a4534ef767309188cee16e4017054cccd":[5,1,0,0,4,10],
+"struct_ogre_bites_1_1_input_listener.html#a61ba63d9edb3d64ef8ef93b0fafa79f4":[5,1,0,0,4,15],
+"struct_ogre_bites_1_1_input_listener.html#a6b5bb758dff77d6de9c6fad00ddbe591":[5,1,0,0,4,12],
+"struct_ogre_bites_1_1_input_listener.html#a76ba51407cec5b5688c94aab2126cd3b":[5,1,0,0,4,4],
+"struct_ogre_bites_1_1_input_listener.html#a7b4d9fcb9c5e6e81e92ab02d485ad510":[5,1,0,0,4,3],
+"struct_ogre_bites_1_1_input_listener.html#aa2e3f9569ad2c28ea0ec5d48b5ddb9e0":[5,1,0,0,4,9],
+"struct_ogre_bites_1_1_input_listener.html#aab02e8b14e95a78dfc5ae694104aef56":[5,1,0,0,4,11],
+"struct_ogre_bites_1_1_input_listener.html#abe5f72cb4f631c440bb5a8f699da90d2":[5,1,0,0,4,2],
+"struct_ogre_bites_1_1_input_listener.html#ac3f2ee3ec9de5a294260880a04ec3259":[5,1,0,0,4,1],
+"struct_ogre_bites_1_1_input_listener.html#ac4a3dc2ca71bdd0e138889050d5be727":[5,1,0,0,4,7],
+"struct_ogre_bites_1_1_input_listener.html#ae2b51ba8087ce895344f6ac2b86e25b2":[5,1,0,0,4,13],
+"struct_ogre_bites_1_1_input_listener.html#aebffd0d3efd1403c3f30ea9bd4290f26":[5,1,0,0,4,14],
+"struct_ogre_bites_1_1_keyboard_event.html":[5,1,0,0,6],
+"struct_ogre_bites_1_1_keyboard_event.html#a2b2b87cad3f82fb272e86c115fc744c8":[5,1,0,0,6,2],
+"struct_ogre_bites_1_1_keyboard_event.html#a43602aaa9c30b36a13c2c4b4eccbecd9":[5,1,0,0,6,0],
+"struct_ogre_bites_1_1_keyboard_event.html#a675789f0663c8e7c8ac38db339a98a60":[5,1,0,0,6,1],
+"struct_ogre_bites_1_1_keysym.html":[5,1,0,0,7],
+"struct_ogre_bites_1_1_keysym.html#a0174848a10c2790beb05a3f21317a5c3":[5,1,0,0,7,0],
+"struct_ogre_bites_1_1_keysym.html#a41e0a1ecbac3b262fe419371ef74da99":[5,1,0,0,7,1],
+"struct_ogre_bites_1_1_mouse_button_event.html":[5,1,0,0,8],
+"struct_ogre_bites_1_1_mouse_button_event.html#a0e23a52e12f37f0021ae358592adc721":[5,1,0,0,8,2],
+"struct_ogre_bites_1_1_mouse_button_event.html#a5a726cd5b2d0ac069c96e8bf85cd93bc":[5,1,0,0,8,1],
+"struct_ogre_bites_1_1_mouse_button_event.html#a83011c2613d0e6c4b4b639a9e727d6b3":[5,1,0,0,8,4],
+"struct_ogre_bites_1_1_mouse_button_event.html#aa676b58a32cec113f18fe1a1ccf5a1c9":[5,1,0,0,8,0],
+"struct_ogre_bites_1_1_mouse_button_event.html#aab3921d012481b923b8e85dc7a9a1059":[5,1,0,0,8,3],
+"struct_ogre_bites_1_1_mouse_motion_event.html":[5,1,0,0,9],
+"struct_ogre_bites_1_1_mouse_motion_event.html#a154f56c1e7973e1093e8e9790b891905":[5,1,0,0,9,2],
+"struct_ogre_bites_1_1_mouse_motion_event.html#a5ec248b9fa2d12b77758b260d6c6d13f":[5,1,0,0,9,0],
+"struct_ogre_bites_1_1_mouse_motion_event.html#a7e5b81289ae8a00f47a2989e809fc944":[5,1,0,0,9,3],
+"struct_ogre_bites_1_1_mouse_motion_event.html#a92edfa8cded01b6b59375a92855a3034":[5,1,0,0,9,1],
+"struct_ogre_bites_1_1_mouse_motion_event.html#a9df7243dbc2adc4deb99da321aae7e96":[5,1,0,0,9,5],
+"struct_ogre_bites_1_1_mouse_motion_event.html#af22000e1b37946e6f4517160ce19562b":[5,1,0,0,9,4],
+"struct_ogre_bites_1_1_mouse_wheel_event.html":[5,1,0,0,10],
+"struct_ogre_bites_1_1_mouse_wheel_event.html#a27ed30513a79d9812254a72e29bf5e11":[5,1,0,0,10,0],
+"struct_ogre_bites_1_1_mouse_wheel_event.html#a94bdc0e9db916b9240048bdb7240488e":[5,1,0,0,10,1],
 "struct_ogre_bites_1_1_native_window_pair.html":[5,1,0,6],
 "struct_ogre_bites_1_1_native_window_pair.html#a0aed6e564ec487d4bfca0dc33d4745f2":[5,1,0,6,0],
 "struct_ogre_bites_1_1_native_window_pair.html#a23343b8cfa075f61094c738adeab3204":[5,1,0,6,1],
-"struct_ogre_bites_1_1_text_input_event.html":[5,1,0,0,10],
-"struct_ogre_bites_1_1_text_input_event.html#acc25a10c4d0a2b280ad7e473e4b6efcb":[5,1,0,0,10,1],
-"struct_ogre_bites_1_1_text_input_event.html#ad28a23d8c9a7f477f279c0c3f158d2be":[5,1,0,0,10,0],
-"struct_ogre_bites_1_1_touch_finger_event.html":[5,1,0,0,11],
-"struct_ogre_bites_1_1_touch_finger_event.html#a286c1673cee6b71b7f0bc6a9c4fb059c":[5,1,0,0,11,2],
-"struct_ogre_bites_1_1_touch_finger_event.html#a35a8a30c41ccf6767b36ecb784a83586":[5,1,0,0,11,4],
-"struct_ogre_bites_1_1_touch_finger_event.html#a56ddc53ca99755dbc2f1f24dc655cd06":[5,1,0,0,11,1],
-"struct_ogre_bites_1_1_touch_finger_event.html#aa57cc08dfd5e0ba9d8a18bb9b37b2fd2":[5,1,0,0,11,3],
-"struct_ogre_bites_1_1_touch_finger_event.html#abc13458fb67ca8baeea63c39a1138e0a":[5,1,0,0,11,5],
-"struct_ogre_bites_1_1_touch_finger_event.html#ae31fc88dca4ae639f130a9206ff64244":[5,1,0,0,11,0],
-"structbsp__brush__t.html":[7,0,3],
-"structbsp__brush__t.html#a0525b4ebc88b426a24ba4ef2a64d1f9e":[7,0,3,0],
-"structbsp__brush__t.html#aa8f2e483aa9cb18168e6d146cc7fb1b2":[7,0,3,1],
-"structbsp__brush__t.html#aca3a9ac86ba907ac43e055d4505f072b":[7,0,3,2],
-"structbsp__brushside__t.html":[7,0,4],
-"structbsp__brushside__t.html#a2538db593bd8c50a52e770fc6ac8456a":[7,0,4,1],
-"structbsp__brushside__t.html#a6091d89170ab0f354f0f573c873346d3":[7,0,4,0],
-"structbsp__face__t.html":[7,0,5],
-"structbsp__face__t.html#a13c0e8661b6ffd6f893b4c35bf7a0022":[7,0,5,5],
-"structbsp__face__t.html#a26742ad3555447b16d7d84a200df90e4":[7,0,5,7],
-"structbsp__face__t.html#a2a6371e0dfe0ca6939fd40da328bffd3":[7,0,5,2],
-"structbsp__face__t.html#a6c520802a723dcf1f887474bab5b415c":[7,0,5,6],
-"structbsp__face__t.html#a8b2ef57308bff5297ca6065a62685f59":[7,0,5,4],
-"structbsp__face__t.html#aa174fa8faa20496d0d789d8ae74dbdde":[7,0,5,13],
-"structbsp__face__t.html#aac42a7e77d3bdd9a6a9e4865201a7d1e":[7,0,5,8],
-"structbsp__face__t.html#ac295aee82ef83a80e6fb6e4123fccd32":[7,0,5,9],
-"structbsp__face__t.html#acca9215f44d568566d4176d162e58a1d":[7,0,5,0],
-"structbsp__face__t.html#ad8ed453e2e0baa9c16ffe543da198956":[7,0,5,11],
-"structbsp__face__t.html#adad5d5d0c0cf88b655bd3e5400bdfb70":[7,0,5,10],
-"structbsp__face__t.html#adf2e01928d721064f72ba3f9c2e6a2fd":[7,0,5,1],
-"structbsp__face__t.html#ae15cbcb6073a8e9d6d07262e50d59f7b":[7,0,5,3],
-"structbsp__face__t.html#ae18796a76c1cc01a88908a91ffbb18b1":[7,0,5,12],
-"structbsp__header__t.html":[7,0,6],
-"structbsp__header__t.html#a3ebea24b318355e48c5035bdca0cfd1c":[7,0,6,2],
-"structbsp__header__t.html#aa06eb21e74349ec2426f5f604caf078e":[7,0,6,0],
-"structbsp__header__t.html#ade484f9e3ff36111728c05894b5abd47":[7,0,6,1],
-"structbsp__leaf__t.html":[7,0,7]
+"struct_ogre_bites_1_1_text_input_event.html":[5,1,0,0,11],
+"struct_ogre_bites_1_1_text_input_event.html#acc25a10c4d0a2b280ad7e473e4b6efcb":[5,1,0,0,11,1],
+"struct_ogre_bites_1_1_text_input_event.html#ad28a23d8c9a7f477f279c0c3f158d2be":[5,1,0,0,11,0],
+"struct_ogre_bites_1_1_touch_finger_event.html":[5,1,0,0,12],
+"struct_ogre_bites_1_1_touch_finger_event.html#a286c1673cee6b71b7f0bc6a9c4fb059c":[5,1,0,0,12,2],
+"struct_ogre_bites_1_1_touch_finger_event.html#a35a8a30c41ccf6767b36ecb784a83586":[5,1,0,0,12,4]
 };
