@@ -12,7 +12,7 @@ var indexSectionsWithContent =
   9: "ago",
   10: "_bcdgmos",
   11: "abcdefgilmoprstv",
-  12: "abcdefghilmnoprstuvwy"
+  12: "012abcdefghijklmnopqrstuvwxyz’"
 };
 
 var indexSectionNames =
